@@ -7,7 +7,7 @@
 class SDLException : public Exception
 {
   public:
-    SDLException(const char *m_call);
+    SDLException(const char *call);
     ~SDLException();
 
     std::string toString() const;
