@@ -57,7 +57,7 @@ namespace SDL_TOOLS
     //------------------------------------------------------------------------
     /**
      * @param src The source surface to rotate.
-     * @param angle The angle (90, 180 or 270).
+     * @param angle The angle (0, 90, 180 or 270).
      *
      * @return A pointer to the new rotated surface.
      *
@@ -65,6 +65,26 @@ namespace SDL_TOOLS
      */
     SDL_Surface *rotate(const SDL_Surface *src, Uint16 angle);
 
+    //------------------------------------------------------------------------
+    /**
+     * @param src The source surface to flip in x-direction.
+     *
+     * @return A pointer to the new flipped surface.
+     *
+     * @throw SDLException if an SDL error occured.
+     */
+    SDL_Surface *flipX(const SDL_Surface *src);
+
+    //------------------------------------------------------------------------
+    /**
+     * @param src The source surface to flip in y-direction.
+     *
+     * @return A pointer to the new flipped surface.
+     *
+     * @throw SDLException if an SDL error occured.
+     */
+    SDL_Surface *flipY(const SDL_Surface *src);
+
     //------------------------------------------------------------------------
     /**
      * @param s1 The first surface.
