@@ -7,7 +7,9 @@
 class SyscallException : public Exception
 {
   public:
+    SyscallException(const char *message);
     SyscallException(const std::string &message);
+    SyscallException(const char *message, int error);
     SyscallException(const std::string &message, int error);
     ~SyscallException();
 
