@@ -597,7 +597,83 @@ SDL_Surface *SDL_TOOLS::rotate(const SDL_Surface *src, Uint16 angle)
         return rotate8bpp_(src, angle);
 
       default:
-        throw SDLException("Unsupported source bpp");
+        throw SDLException("SDL_TOOLS::rotate(): Unsupported source bpp");
+    }
+}
+
+//----------------------------------------------------------------------------
+static SDL_Surface *flipX8bpp_(const SDL_Surface *src)
+{
+    SDL_Surface *dst = SDL_CALLS::CreateRGBSurface(
+        SDL_SWSURFACE, src->w, src->h, 32);
+
+    Uint8 *srcPixels = (Uint8*)src->pixels;
+    Uint8 *dstPixels = (Uint8*)dst->pixels;
+    Uint8 r, g, b;
+
+    for (Sint32 y=0; y<src->h; y++)
+    {
+        for (Sint32 x=0; x<src->w; x++)
+        {
+            SDL_GetRGB(
+                *(srcPixels + y*src->pitch + x), src->format, &r, &g, &b);
+            
+            *(Uint32*)(dstPixels + y*dst->pitch + (dst->w - x - 1)*4) =
+                SDL_MapRGB(dst->format, r, g, b);
+        }
+    }
+
+    return dst;
+}
+
+//----------------------------------------------------------------------------
+SDL_Surface *SDL_TOOLS::flipX(const SDL_Surface *src)
+{
+    switch (src->format->BitsPerPixel)
+    {
+      case 8:
+        return flipX8bpp_(src);
+
+      default:
+        throw SDLException("SDL_TOOLS::flipX(): Unsupported source bpp");
+    }
+}
+
+//----------------------------------------------------------------------------
+static SDL_Surface *flipY8bpp_(const SDL_Surface *src)
+{
+    SDL_Surface *dst = SDL_CALLS::CreateRGBSurface(
+        SDL_SWSURFACE, src->w, src->h, 32);
+
+    Uint8 *srcPixels = (Uint8*)src->pixels;
+    Uint8 *dstPixels = (Uint8*)dst->pixels;
+    Uint8 r, g, b;
+
+    for (Sint32 y=0; y<src->h; y++)
+    {
+        for (Sint32 x=0; x<src->w; x++)
+        {
+            SDL_GetRGB(
+                *(srcPixels + y*src->pitch + x), src->format, &r, &g, &b);
+            
+            *(Uint32*)(dstPixels + (dst->h - y - 1)*dst->pitch + x*4) =
+                SDL_MapRGB(dst->format, r, g, b);
+        }
+    }
+
+    return dst;
+}
+
+//----------------------------------------------------------------------------
+SDL_Surface *SDL_TOOLS::flipY(const SDL_Surface *src)
+{
+    switch (src->format->BitsPerPixel)
+    {
+      case 8:
+        return flipY8bpp_(src);
+
+      default:
+        throw SDLException("SDL_TOOLS::flipY(): Unsupported source bpp");
     }
 }
 
