@@ -101,6 +101,7 @@ public:
     bool isEOF() const;
 
     void seek(long offset);
+    long tell() const;
 
     size_t read(void *buffer, size_t len);
     size_t write(const void *buffer, size_t len);
@@ -158,6 +159,18 @@ void File::PImpl::seek(long offset)
     }
 }
 
+//----------------------------------------------------------------------------
+long File::PImpl::tell() const
+{
+    long rc = ftell(m_file);
+    if (rc == -1)
+    {
+        throw SyscallException("Cannot tell current position in file");
+    }
+
+    return rc;
+}
+
 //----------------------------------------------------------------------------
 size_t File::PImpl::read(void *buffer, size_t len)
 {
@@ -249,6 +262,12 @@ void File::seek(long offset)
     m_pImpl->seek(offset);
 }
 
+//----------------------------------------------------------------------------
+long File::tell() const
+{
+    return m_pImpl->tell();
+}
+
 
 //----------------------------------------------------------------------------
 uint8_t File::readUint8()
