@@ -26,9 +26,6 @@ class GameBridge : public GameInterface
     int getYVelocity(const SDL_Rect &r) const;
     unsigned getFriction(const SDL_Rect &r) const;
 
-    void addObjectToPlayGround(ObjectBase *o);
-    void addParticleToPlayGround(ParticleBase *p);
-
     bool isBackgroundBetween(Uint16 x1, Uint16 y1, Uint16 x2, Uint16 y2) const;
 
     const Platform *isInLandingZone(const Ship *s) const;
