@@ -84,6 +84,7 @@ class GameControlBase
     {
         GAME_STATE_OBJECT(Running)
 
+        void onPreUpdate(GameControlBase *game);
         void onShipLanded(Ship *ship, const Platform *platform,
                           GameControlBase *game);
     };
@@ -441,7 +442,7 @@ class GameControlBase
     /// Called for a Ship-PlayGround collision.
     void onCollision(Ship *ship);
 
-    void onCollision(Ship *ship, GrenadeBase *grenade);
+    void onCollision(Ship *ship, Grenade *grenade);
     void onCollision(Ship *ship, Missile *missile);
     void onCollision(Ship *ship, MortarBase *mortar);
     void onCollision(Ship *ship, ProjectileBase *projectile);
@@ -452,7 +453,7 @@ class GameControlBase
     /// Called for a Missile-PlayGround collision.
     void onCollision(Missile *missile);
 
-    void onCollision(Missile *missile, GrenadeBase *grenade);
+    void onCollision(Missile *missile, Grenade *grenade);
     void onCollision(Missile *missile, MortarBase *mortar);
     void onCollision(Missile *missile, ProjectileBase *projectile);
     void onCollision(Missile *missile, SAMBatteryBase *sam);
@@ -460,13 +461,13 @@ class GameControlBase
     void onCollision(Missile *missile, Tank *tank);
     void onCollision(Missile *missile, TurretBase *turret);
 
-    /// Called for a GrenadeBase-PlayGround collision.
-    void onCollision(GrenadeBase *grenade);
+    /// Called for a Grenade-PlayGround collision.
+    void onCollision(Grenade *grenade);
 
-    void onCollision(GrenadeBase *grenade, MortarBase *mortar);
-    void onCollision(GrenadeBase *grenade, SwitchBase *s);
-    void onCollision(GrenadeBase *grenade, Tank *tank);
-    void onCollision(GrenadeBase *grenade, TurretBase *turret);
+    void onCollision(Grenade *grenade, MortarBase *mortar);
+    void onCollision(Grenade *grenade, SwitchBase *s);
+    void onCollision(Grenade *grenade, Tank *tank);
+    void onCollision(Grenade *grenade, TurretBase *turret);
 
     /// Called for a ProjectileBase-PlayGround collision.
     void onCollision(ProjectileBase *projectile);
@@ -494,7 +495,7 @@ class GameControlBase
     void do_updateBonus();
 
     //------------------------------------------------------------------------
-    void do_explode(GrenadeBase *grenade);
+    void do_explode(Grenade *grenade);
     void do_explode(Missile *missile);
     void do_explode(MortarBase *mortar);
     void do_explode(ProjectileBase *projectile);
