@@ -59,7 +59,7 @@ class OverdrawObjectsConstVisitor : public ObjectConstVisitor
     void do_visit(const Barrier *b) { do_do_visit(b); }
     void do_visit(const BlackHole *b) { do_do_visit(b); }
     void do_visit(const Crate *c) { do_do_visit(c); }
-    void do_visit(const GrenadeBase *g) { do_do_visit(g); }
+    void do_visit(const Grenade *g) { do_do_visit(g); }
     void do_visit(const Grinder *g) { do_do_visit(g); }
     void do_visit(const MagnetBase *m) { do_do_visit(m); }
     void do_visit(const Missile *m) { do_do_visit(m); }
@@ -72,6 +72,7 @@ class OverdrawObjectsConstVisitor : public ObjectConstVisitor
     void do_visit(const Ship *s) { do_do_visit(s); }
     void do_visit(const SwitchBase *s) { do_do_visit(s); }
     void do_visit(const Tank *t) { do_do_visit(t); }
+    void do_visit(const Thorn *t) { do_do_visit(t); }
     void do_visit(const TurretBase *t) { do_do_visit(t); }
 
     //------------------------------------------------------------------------
@@ -101,7 +102,7 @@ class UpdateObjectsVisitor : public ObjectVisitor
     void do_visit(Barrier *b) { do_do_visit(b); }
     void do_visit(BlackHole *b) { do_do_visit(b); }
     void do_visit(Crate *c) { do_do_visit(c); }
-    void do_visit(GrenadeBase *g);
+    void do_visit(Grenade *g);
     void do_visit(Grinder *g) { do_do_visit(g); }
     void do_visit(MagnetBase *m) { do_do_visit(m); }
     void do_visit(Missile *m);
@@ -114,6 +115,7 @@ class UpdateObjectsVisitor : public ObjectVisitor
     void do_visit(Ship *s);
     void do_visit(SwitchBase *s) { do_do_visit(s); }
     void do_visit(Tank *t) { do_do_visit(t); }
+    void do_visit(Thorn *t) { do_do_visit(t); }
     void do_visit(TurretBase *t) { do_do_visit(t); }
 
     //------------------------------------------------------------------------
@@ -150,6 +152,7 @@ class CollisionDetectorVisitor : public ObjectVisitor
         void do_visit(MagnetBase *m) { do_onCollision(m); }
         void do_visit(ParticleFountainBase *f) { do_onCollision(f); }
         void do_visit(Platform *p) { do_onCollision(p); }
+        void do_visit(Thorn *t) { do_onCollision(t); }
 
         virtual void do_onCollision(ObjectBase *o) = 0;
 
@@ -169,7 +172,7 @@ class CollisionDetectorVisitor : public ObjectVisitor
 
       private:
         //--------------------------------------------------------------------
-        void do_visit(GrenadeBase *g) { do_onCollision(g); }
+        void do_visit(Grenade *g) { do_onCollision(g); }
         void do_visit(Missile *m) { do_onCollision(m); }
         void do_visit(MortarBase *m) { do_onCollision(m); }
         void do_visit(SAMBatteryBase *s) { do_onCollision(s); }
@@ -196,7 +199,7 @@ class CollisionDetectorVisitor : public ObjectVisitor
 
       private:
         //--------------------------------------------------------------------
-        void do_visit(GrenadeBase *g);
+        void do_visit(Grenade *g);
         void do_visit(Missile *m);
         void do_visit(MortarBase *m);
         void do_visit(ProjectileBase *p);
@@ -223,7 +226,7 @@ class CollisionDetectorVisitor : public ObjectVisitor
 
       private:
         //--------------------------------------------------------------------
-        void do_visit(GrenadeBase *g);
+        void do_visit(Grenade *g);
         void do_visit(MortarBase *m);
         void do_visit(ProjectileBase *p);
         void do_visit(SwitchBase *s);
@@ -244,7 +247,7 @@ class CollisionDetectorVisitor : public ObjectVisitor
     {
       public:
         //--------------------------------------------------------------------
-        GrenadeCollisionDetectorVisitor(GrenadeBase *grenade)
+        GrenadeCollisionDetectorVisitor(Grenade *grenade)
             : m_grenade(grenade) {}
         ~GrenadeCollisionDetectorVisitor() { m_grenade = NULL; }
 
@@ -260,7 +263,7 @@ class CollisionDetectorVisitor : public ObjectVisitor
         void do_onCollision(ObjectBase *o);
         
         //--------------------------------------------------------------------
-        GrenadeBase *m_grenade;
+        Grenade *m_grenade;
     };
 
     //------------------------------------------------------------------------
@@ -299,47 +302,49 @@ class CollisionDetectorVisitor : public ObjectVisitor
     void do_visit(ParticleBase *p);
     void do_visit(Ship *s);
     void do_visit(Missile *m);
-    void do_visit(GrenadeBase *g);
+    void do_visit(Grenade *g);
     void do_visit(ProjectileBase *p);
 };
 
 
 //----------------------------------------------------------------------------
 /**
- * This const visitor walks through an ObjectList,
- * and will blit each object to the given shadow surface of the PlayGround.
+ * This visitor is used to walk through an ObjectList,
+ * calling updateSurface() of all objects
+ * and blitting all objects to the given shadow surface of the PlayGround.
  */
-class BlitObjectsConstVisitor : public ObjectConstVisitor
+class BlitObjectsVisitor : public ObjectVisitor
 {
   public:
     //------------------------------------------------------------------------
-    BlitObjectsConstVisitor(SDL_Surface *shadowSurface)
+    BlitObjectsVisitor(SDL_Surface *shadowSurface)
         : m_shadowSurface(shadowSurface) {}
-    ~BlitObjectsConstVisitor() { m_shadowSurface = NULL; }
+    ~BlitObjectsVisitor() { m_shadowSurface = NULL; }
 
   private:
     //------------------------------------------------------------------------
-    void do_visit(const Barrier *b) { do_do_visit(b); }
-    void do_visit(const BlackHole *b) { do_do_visit(b); }
-    void do_visit(const Crate *c) { do_do_visit(c); }
-    void do_visit(const GrenadeBase *g) { do_do_visit(g); }
-    void do_visit(const Grinder *g) { do_do_visit(g); }
-    void do_visit(const MagnetBase *m) { do_do_visit(m); }
-    void do_visit(const Missile *m) { do_do_visit(m); }
-    void do_visit(const MortarBase *m) { do_do_visit(m); }
-    void do_visit(const ParticleBase *p);
-    void do_visit(const ParticleFountainBase *f) { do_do_visit(f); }
-    void do_visit(const Platform *p) { do_do_visit(p); }
-    void do_visit(const ProjectileBase *p) { do_do_visit(p); }
-    void do_visit(const SAMBatteryBase *s) { do_do_visit(s); }
-    void do_visit(const Ship *s) { do_do_visit(s); }
-    void do_visit(const SwitchBase *s) { do_do_visit(s); }
-    void do_visit(const Tank *t) { do_do_visit(t); }
-    void do_visit(const TurretBase *t) { do_do_visit(t); }
+    void do_visit(Barrier *b) { do_do_visit(b); }
+    void do_visit(BlackHole *b) { do_do_visit(b); }
+    void do_visit(Crate *c) { do_do_visit(c); }
+    void do_visit(Grenade *g) { do_do_visit(g); }
+    void do_visit(Grinder *g) { do_do_visit(g); }
+    void do_visit(MagnetBase *m) { do_do_visit(m); }
+    void do_visit(Missile *m) { do_do_visit(m); }
+    void do_visit(MortarBase *m) { do_do_visit(m); }
+    void do_visit(ParticleBase *p);
+    void do_visit(ParticleFountainBase *f) { do_do_visit(f); }
+    void do_visit(Platform *p) { do_do_visit(p); }
+    void do_visit(ProjectileBase *p) { do_do_visit(p); }
+    void do_visit(SAMBatteryBase *s) { do_do_visit(s); }
+    void do_visit(Ship *s) { do_do_visit(s); }
+    void do_visit(SwitchBase *s) { do_do_visit(s); }
+    void do_visit(Tank *t) { do_do_visit(t); }
+    void do_visit(Thorn *t) { do_do_visit(t); }
+    void do_visit(TurretBase *t) { do_do_visit(t); }
 
     //------------------------------------------------------------------------
     /// A common implementation is used for all type of objects.
-    void do_do_visit(const ObjectBase *o);
+    void do_do_visit(ObjectBase *o);
 
     //------------------------------------------------------------------------
     SDL_Surface *m_shadowSurface;
