@@ -250,22 +250,39 @@ class PlayerConfiguration
         };
 
         //--------------------------------------------------------------------
-        Graphics() { m_fullScreen = false; }
+        Graphics()
+        {
+            m_fullScreen = false;
+            m_fullFrameRate = true;
+        }
+
         ~Graphics() {}
 
+        //--------------------------------------------------------------------
         inline bool isFullScreen() const
         {
             return m_fullScreen;
         }
 
-        inline void setFullScreen(bool fullScreen)
+        inline void setFullScreen(bool enable)
         {
-            m_fullScreen = fullScreen;
+            m_fullScreen = enable;
+        }
+
+        inline bool isFullFrameRate() const
+        {
+            return m_fullFrameRate;
+        }
+
+        inline void setFullFrameRate(bool enable)
+        {
+            m_fullFrameRate = enable;
         }
 
       private:
         //--------------------------------------------------------------------
         bool m_fullScreen;
+        bool m_fullFrameRate;
     };
 
 
@@ -559,8 +576,7 @@ class PlayerConfiguration
 
 
     //------------------------------------------------------------------------
-    static void create() throw (Exception);
-
+    static void create();
     static void destroy();
 
     inline static PlayerConfiguration* getInstance()
@@ -571,8 +587,8 @@ class PlayerConfiguration
   private:
 
     //-----------------------------------------------------------------------
-    void loadConfiguration() throw (Exception);
-    void loadHighscore() throw (Exception);
+    void loadConfiguration();
+    void loadHighscore();
 
 
     //------------------------------------------------------------------------
