@@ -18,13 +18,10 @@
 #include "ScoreTable.h"
 #include "PlayerConfiguration.h"
 #include "PlayGround.h"
+#include "GameRecorder.h"
 #include "GameControlBase.h"
 
 
-//----------------------------------------------------------------------------
-typedef std::set<unsigned> UnsignedSet;
-
-
 //----------------------------------------------------------------------------
 GameControlBase::Running GameControlBase::Running::sm_instance;
 GameControlBase::UnloadingCrate GameControlBase::UnloadingCrate::sm_instance;
@@ -85,6 +82,18 @@ void GameControlBase::GameStateBase::onPlayerShipDestroyed(
 }
 
 
+//----------------------------------------------------------------------------
+void GameControlBase::Running::onPreUpdate(GameControlBase *game)
+{
+    Ship *ship = game->getPlayerShip();
+    const Platform *landedPlatform = ship->getLandedPlatform();
+
+    if (landedPlatform != NULL && landedPlatform->isFuelPlatform())
+    {
+        ship->incFuel(5, game->getPlayerFuel());
+    }
+}
+
 //----------------------------------------------------------------------------
 void GameControlBase::Running::onShipLanded(
     Ship *ship, const Platform *platform, GameControlBase *game)
@@ -570,7 +579,7 @@ void GameControlBase::onCollision(Ship *ship)
 }
 
 //----------------------------------------------------------------------------
-void GameControlBase::onCollision(Ship *ship, GrenadeBase *grenade)
+void GameControlBase::onCollision(Ship *ship, Grenade *grenade)
 {
     do_explode(ship);
     do_explode(grenade);
@@ -659,7 +668,7 @@ void GameControlBase::onCollision(Missile *missile)
 }
 
 //----------------------------------------------------------------------------
-void GameControlBase::onCollision(Missile *missile, GrenadeBase *grenade)
+void GameControlBase::onCollision(Missile *missile, Grenade *grenade)
 {
     do_explode(missile);
     do_explode(grenade);
@@ -745,13 +754,13 @@ void GameControlBase::onCollision(Missile *missile, TurretBase *turret)
 
 
 //----------------------------------------------------------------------------
-void GameControlBase::onCollision(GrenadeBase *grenade)
+void GameControlBase::onCollision(Grenade *grenade)
 {
     do_explode(grenade);
 }
 
 //----------------------------------------------------------------------------
-void GameControlBase::onCollision(GrenadeBase *grenade, MortarBase *mortar)
+void GameControlBase::onCollision(Grenade *grenade, MortarBase *mortar)
 {
     do_explode(grenade);
     do_explode(mortar);
@@ -764,14 +773,14 @@ void GameControlBase::onCollision(GrenadeBase *grenade, MortarBase *mortar)
 }
 
 //----------------------------------------------------------------------------
-void GameControlBase::onCollision(GrenadeBase *grenade, SwitchBase *s)
+void GameControlBase::onCollision(Grenade *grenade, SwitchBase *s)
 {
     do_explode(grenade);
     s->toggle();
 }
 
 //----------------------------------------------------------------------------
-void GameControlBase::onCollision(GrenadeBase *grenade, Tank *tank)
+void GameControlBase::onCollision(Grenade *grenade, Tank *tank)
 {
     do_explode(grenade);
     do_explode(tank);
@@ -784,7 +793,7 @@ void GameControlBase::onCollision(GrenadeBase *grenade, Tank *tank)
 }
 
 //----------------------------------------------------------------------------
-void GameControlBase::onCollision(GrenadeBase *grenade, TurretBase *turret)
+void GameControlBase::onCollision(Grenade *grenade, TurretBase *turret)
 {
     do_explode(grenade);
     do_explode(turret);
@@ -929,7 +938,7 @@ void GameControlBase::handleEvents(const XMLNode *node)
 
 
 //----------------------------------------------------------------------------
-void GameControlBase::do_explode(GrenadeBase *grenade)
+void GameControlBase::do_explode(Grenade *grenade)
 {
     CreateExplosionParticleConstVisitor v;
     grenade->accept(v);
@@ -1240,6 +1249,8 @@ void GameControlBase::update()
     onPreUpdate();
     PlayGround::getInstance()->update();
     onPostUpdate();
+
+    //GameRecorder::getInstance()->writeFrame();
 }
 
 
