@@ -576,14 +576,14 @@ void PlayGround::update()
 
     r->removeObjectsToRemove();
 
-    BlitObjectsConstVisitor v4(m_shadowSurface);
+    BlitObjectsVisitor v4(m_shadowSurface);
     r->acceptAll(v4);
 }
 
 //----------------------------------------------------------------------------
 void PlayGround::updateForPreview()
 {
-    BlitObjectsConstVisitor v(m_shadowSurface);
+    BlitObjectsVisitor v(m_shadowSurface);
     ObjectRepository::getInstance()->acceptObjects(v);
 }
 
@@ -613,7 +613,7 @@ void OverdrawObjectsConstVisitor::do_do_visit(const ObjectBase *o)
 
 
 //----------------------------------------------------------------------------
-void UpdateObjectsVisitor::do_visit(GrenadeBase *g)
+void UpdateObjectsVisitor::do_visit(Grenade *g)
 {
     do_do_visit(g);
 
@@ -681,7 +681,7 @@ void CollisionDetectorVisitor::ParticleCollisionDetectorVisitor::do_onCollision(
 
 
 //----------------------------------------------------------------------------
-void CollisionDetectorVisitor::ShipCollisionDetectorVisitor::do_visit(GrenadeBase *g)
+void CollisionDetectorVisitor::ShipCollisionDetectorVisitor::do_visit(Grenade *g)
 {
     if (ObjectBase::isCollision(m_ship, g))
     {
@@ -762,7 +762,7 @@ void CollisionDetectorVisitor::ShipCollisionDetectorVisitor::do_onCollision(Obje
 
 
 //----------------------------------------------------------------------------
-void CollisionDetectorVisitor::MissileCollisionDetectorVisitor::do_visit(GrenadeBase *g)
+void CollisionDetectorVisitor::MissileCollisionDetectorVisitor::do_visit(Grenade *g)
 {
     if (ObjectBase::isCollision(m_missile, g))
     {
@@ -993,7 +993,7 @@ void CollisionDetectorVisitor::do_visit(Missile *m)
 }
 
 //----------------------------------------------------------------------------
-void CollisionDetectorVisitor::do_visit(GrenadeBase *g)
+void CollisionDetectorVisitor::do_visit(Grenade *g)
 {
     PlayGround *playGround = PlayGround::getInstance();
 
@@ -1026,10 +1026,12 @@ void CollisionDetectorVisitor::do_visit(ProjectileBase *p)
 
 
 //----------------------------------------------------------------------------
-void BlitObjectsConstVisitor::do_visit(const ParticleBase *p)
+void BlitObjectsVisitor::do_visit(ParticleBase *p)
 {
     // This is an optimized version of do_do_visit(p);
 
+    p->updateSurface();
+
     const SDL_Rect &pos = p->getPosition();
     const SDL_Surface *surface = p->getSurface();
 
@@ -1040,7 +1042,8 @@ void BlitObjectsConstVisitor::do_visit(const ParticleBase *p)
 }
 
 //----------------------------------------------------------------------------
-void BlitObjectsConstVisitor::do_do_visit(const ObjectBase *o)
+void BlitObjectsVisitor::do_do_visit(ObjectBase *o)
 {
+    o->updateSurface();
     o->blitTo(m_shadowSurface);
 }
