@@ -1,6 +1,9 @@
 #include <iostream>
+#include <fstream>
 
 #include "config.h"
+#include "Exception.h"
+#include "File.h"
 #include "Directory.h"
 #include "Configuration.h"
 #include "XMLParser.h"
@@ -238,6 +241,10 @@ void PlayerConfiguration::Graphics::ReadVisitor::do_visit(const XMLNode *n)
     {
         m_graphics->setFullScreen(n->getBoolProperty("enabled"));
     }
+    else if (n->getName() == "fullframerate")
+    {
+        m_graphics->setFullFrameRate(n->getBoolProperty("enabled"));
+    }
 }
 
 //----------------------------------------------------------------------------
@@ -252,6 +259,11 @@ void PlayerConfiguration::Graphics::WriteVisitor::do_visit(XMLNode *n)
         n->getMandatoryProperty("enabled")->setValue(
             m_graphics->isFullScreen());
     }
+    else if (n->getName() == "fullframerate")
+    {
+        n->getMandatoryProperty("enabled")->setValue(
+            m_graphics->isFullFrameRate());
+    }
 }
 
 
@@ -564,114 +576,9 @@ private:
     XMLNode *m_newKeyboard;
 };
 
-//----------------------------------------------------------------------------
-/**
- * @todo: Remove this function, in one of the next releases.
- */
-static bool g_migrateOldConfig(const Directory &homeMoaggDir) throw (Exception)
-{
-    const char *controlFile = "controls.xml";
-    const char *playerFile = "player.xml";
-    const char *soundFile = "sound.xml";
-
-    if (!homeMoaggDir.hasFile(controlFile) ||
-        !homeMoaggDir.hasFile(playerFile) ||
-        !homeMoaggDir.hasFile(soundFile))
-    {
-        return false;
-    }
-
-    std::cout << "Migrating old config files to new format ... " << std::flush;
-
-    // Parse the old config files.
-
-    XMLNode player;
-    XMLNode controls;
-    XMLNode sound;
-
-    XMLParser p;
-    p.parse(std::string(homeMoaggDir.getName())
-            .append("/").append(playerFile).c_str(), player);
-    p.parse(std::string(homeMoaggDir.getName())
-            .append("/").append(controlFile).c_str(), controls);
-    p.parse(std::string(homeMoaggDir.getName())
-            .append("/").append(soundFile).c_str(), sound);
-
-    // Create the new config structure.
-
-    XMLNode newRoot;
-    XMLNode *newConfig = new XMLNode("config");
-    newConfig->addProperty(new XMLProperty("version", PACKAGE_VERSION));
-
-    XMLNode *newPlayer = new XMLNode("player");
-    newPlayer->addProperty(
-        new XMLProperty(
-            "name", player.getMandatoryNode("player")->getMandatoryNode("name")
-            ->getStringProperty("value")));
-    newPlayer->addProperty(new XMLProperty("shiptype", 0));
-    newConfig->addNode(newPlayer);
-
-    XMLNode *newControl = new XMLNode("control");
-    XMLNode *newKeyboard = new XMLNode("keyboard");
-    GMigrateOldConfigControlVisitor v(newKeyboard);
-    controls.getMandatoryNode("keyboard")->accept(v);
-    newControl->addNode(newKeyboard);
-    newConfig->addNode(newControl);
-
-    XMLNode *newGraphics = new XMLNode("graphics");
-    XMLNode *newFullScreen = new XMLNode("fullscreen");
-    newFullScreen->addProperty(new XMLProperty("enabled", "0"));
-    newGraphics->addNode(newFullScreen);
-    newConfig->addNode(newGraphics);
-
-    XMLNode *newSound = new XMLNode("sound");
-    XMLNode *newSfx = new XMLNode("sfx");
-    newSfx->addProperty(
-        new XMLProperty(
-            "enabled", sound.getMandatoryNode("soundconfig")
-            ->getMandatoryNode("sound")->getBoolProperty("enabled")));
-    newSfx->addProperty(
-        new XMLProperty(
-            "volume", sound.getMandatoryNode("soundconfig")
-            ->getMandatoryNode("sound")->getUnsignedProperty("volume")));
-    newSound->addNode(newSfx);
-    XMLNode *newMusic = new XMLNode("music");
-    newMusic->addProperty(
-        new XMLProperty(
-            "enabled", sound.getMandatoryNode("soundconfig")
-            ->getMandatoryNode("music")->getBoolProperty("enabled")));
-    newMusic->addProperty(
-        new XMLProperty(
-            "volume", sound.getMandatoryNode("soundconfig")
-            ->getMandatoryNode("music")->getUnsignedProperty("volume")));
-    newSound->addNode(newMusic);
-    newConfig->addNode(newSound);
-
-    XMLNode *newMission = new XMLNode("mission");
-    newConfig->addNode(newMission);
-
-    newRoot.addNode(newConfig);
-
-    XMLWriteToFileVisitor w(
-        std::string(homeMoaggDir.getName()).append("/config.xml").c_str());
-    newRoot.accept(w);
-
-    File::unlink(
-        std::string(homeMoaggDir.getName())
-        .append("/").append(playerFile).c_str());
-    File::unlink(
-        std::string(homeMoaggDir.getName())
-        .append("/").append(controlFile).c_str());
-    File::unlink(
-        std::string(homeMoaggDir.getName())
-        .append("/").append(soundFile).c_str());
-
-    return true;
-}
-
 //----------------------------------------------------------------------------
 static bool g_updateConfig(const Directory &homeMoaggDir,
-                           const char *configFile) throw (Exception)
+                           const char *configFile)
 {
     bool updated = false;
 
@@ -685,33 +592,48 @@ static bool g_updateConfig(const Directory &homeMoaggDir,
 
     XMLNode *config = root.getMandatoryNode("config");
 
-    if (config->getMandatoryProperty("version")->getValue() != "0.11")
+    if (config->getMandatoryProperty("version")->getValue() != PACKAGE_VERSION)
     {
         std::cout << "Updating version in config file ... " << std::flush;
 
-        config->getMandatoryProperty("version")->setValue("0.11");
+        config->getMandatoryProperty("version")->setValue(PACKAGE_VERSION);
 
         updated = true;
     }
 
-    if (!config->hasNode("graphics"))
+    XMLNode *graphics = config->getNode("graphics");
+    if (graphics == NULL)
     {
         std::cout << "Adding graphics node to config file ... " << std::flush;
 
-        XMLNode *graphics = new XMLNode("graphics");
+        graphics = new XMLNode("graphics");
         XMLNode *fullScreen = new XMLNode("fullscreen");
         fullScreen->addProperty(new XMLProperty("enabled", "0"));
         graphics->addNode(fullScreen);
+        XMLNode *fullFrameRate = new XMLNode("fullframerate");
+        fullFrameRate->addProperty(new XMLProperty("enabled", "1"));
+        graphics->addNode(fullFrameRate);
 
         config->addNode(graphics);
 
         updated = true;
     }
+    else if (!graphics->hasNode("fullframerate"))
+    {
+        std::cout << "Adding fullframerate child node to graphics node ... " << std::flush;
+
+        XMLNode *fullFrameRate = new XMLNode("fullframerate");
+        fullFrameRate->addProperty(new XMLProperty("enabled", "1"));
+        graphics->addNode(fullFrameRate);
+        
+        updated = true;
+    }
 
     if (updated)
     {
-        XMLWriteToFileVisitor w(file.c_str());
-        root.accept(w);
+        std::ofstream f(file.c_str());
+        XMLWriteToStreamVisitor v(f);
+        root.accept(v);
     }
 
     return updated;
@@ -753,13 +675,10 @@ PlayerConfiguration::PlayerConfiguration()
     }
     else
     {
-        if (!g_migrateOldConfig(homeMoaggDir))
-        {
-            std::cout << "Copying default config file to '"
-                      << homePath << std::endl;
-            std::string globalConfigFile = globalPath + configFile;
-            File::copy(globalConfigFile.c_str(), m_configFile.c_str());
-        }
+        std::cout << "Copying default config file to '"
+                  << homePath << std::endl;
+        std::string globalConfigFile = globalPath + configFile;
+        File::copy(globalConfigFile.c_str(), m_configFile.c_str());
     }
 
     if (!homeMoaggDir.hasFile(highscoreFile))
@@ -776,7 +695,7 @@ PlayerConfiguration::~PlayerConfiguration()
 
 
 //----------------------------------------------------------------------------
-void PlayerConfiguration::loadConfiguration() throw (Exception)
+void PlayerConfiguration::loadConfiguration()
 {
     XMLParser p;
     p.parse(m_configFile.c_str(), m_configRoot);
@@ -786,7 +705,7 @@ void PlayerConfiguration::loadConfiguration() throw (Exception)
 }
 
 //----------------------------------------------------------------------------
-void PlayerConfiguration::loadHighscore() throw (Exception)
+void PlayerConfiguration::loadHighscore()
 {
     XMLParser p;
     p.parse(m_highscoreFile.c_str(), m_highscoreRoot);
@@ -803,7 +722,8 @@ void PlayerConfiguration::writeConfiguration()
         WriteConfigVisitor v1(this);
         m_configRoot.getMandatoryNode("config")->accept(v1);
 
-        XMLWriteToFileVisitor v2(m_configFile.c_str());
+        std::ofstream f(m_configFile.c_str());
+        XMLWriteToStreamVisitor v2(f);
         m_configRoot.accept(v2);
     }
     catch (Exception &e)
@@ -820,7 +740,8 @@ void PlayerConfiguration::writeHighscore()
         XMLNode *highscoreNode = m_highscoreRoot.getMandatoryNode("highscore");
         m_highscore.updateHighscoreNode(highscoreNode);
 
-        XMLWriteToFileVisitor v(m_highscoreFile.c_str());
+        std::ofstream f(m_highscoreFile.c_str());
+        XMLWriteToStreamVisitor v(f);
         m_highscoreRoot.accept(v);
     }
     catch (Exception &e)
@@ -831,7 +752,7 @@ void PlayerConfiguration::writeHighscore()
 
 
 //----------------------------------------------------------------------------
-void PlayerConfiguration::create() throw (Exception)
+void PlayerConfiguration::create()
 {
     if (sm_instance == NULL)
     {
