@@ -165,18 +165,33 @@ const SDL_Surface *Tiles::createTile(Uint8 alpha, Uint8 brightness,
     SDL_Surface *s = SDL_CALLS::CreateRGBSurface(
         SDL_SWSURFACE, iter2->second->w, iter2->second->h, 32);
 
-    assert(brightness <= 0x80);  // 0x81 .. 0xff not implemented yet!
+    if (brightness <= 0x80)
+    {
+        // The brightness levels from normal to black are reached by setting
+        // an apropriate alpha value and blitting to a black surface.
 
-    // The brightness levels from normal to black are reached
-    // by setting an apropriate alpha value and blitting to a black surface.
+        SDL_CALLS::SetAlpha(iter2->second, SDL_SRCALPHA,
+                            brightness == 0x80 ? 0xff : 2*brightness);
+        SDL_CALLS::BlitSurface(iter2->second, NULL, s, NULL);
+        SDL_CALLS::SetAlpha(iter2->second, SDL_SRCALPHA, SDL_ALPHA_OPAQUE);
+    }
+    else
+    {
+        // The brightness levels from normal to white are reached by setting
+        // an apropriate alpha value and blitting to a white surface.
 
-    SDL_CALLS::SetAlpha(iter2->second, SDL_SRCALPHA,
-                        brightness >= 0x80 ? 0xff : 2*brightness);
-    SDL_CALLS::BlitSurface(iter2->second, NULL, s, NULL);
-    SDL_CALLS::SetAlpha(iter2->second, SDL_SRCALPHA, SDL_ALPHA_OPAQUE);
+        SDL_Rect r = { 0, 0, s->w, s->h };
+        SDL_CALLS::FillRect(s, &r, SDL_MapRGB(s->format, 0xff, 0xff, 0xff));
 
-    SDL_CALLS::SetColorKey(s, SDL_SRCCOLORKEY, SDL_MapRGB(s->format, 0, 0, 0));
+        SDL_CALLS::SetAlpha(iter2->second, SDL_SRCALPHA, 2*(0xff-brightness));
+        SDL_CALLS::BlitSurface(iter2->second, NULL, s, NULL);
+        SDL_CALLS::SetAlpha(iter2->second, SDL_SRCALPHA, SDL_ALPHA_OPAQUE);
+    }
+
+    SDL_CALLS::SetColorKey(
+        s, SDL_SRCCOLORKEY, SDL_MapRGB(s->format, 0, 0, 0));
     SDL_CALLS::SetAlpha(s, SDL_SRCALPHA, alpha);
+
     iter->second[abKey] = s;
 
     return s;
