@@ -17,11 +17,15 @@ class GraphicsMenu : public Menu
     PARAGUI_CALLBACK(onOk);
     PARAGUI_CALLBACK(onCancel);
     PARAGUI_CALLBACK(onFullScreenCheck);
+    PARAGUI_CALLBACK(onFullFrameRateCheck);
 
 
     bool m_fullScreenEnabled;
     bool m_lastFullScreenEnabled;
 
+    bool m_fullFrameRateEnabled;
+    bool m_lastFullFrameRateEnabled;
+
     bool m_autoPress;
 };
 
