@@ -48,7 +48,7 @@ class LevelSelectorMenu : public Menu
     std::vector<std::string> m_levelNames;
     std::vector<std::string> m_fullLevelNames;
     std::vector<size_t> m_numberOfLevels;
-    int m_selectedIndex;
+    long m_selectedIndex;
 };
 
 #endif // LEVEL_SELECT_MENU_H
