@@ -4,7 +4,6 @@
 #include <pgwidget.h>
 #include <pgeventobject.h>
 
-#include "GuiException.h"
 #include "MenuSingleton.h"
 #include "MenuManager.h"
 
@@ -24,9 +23,9 @@ class Menu : public PG_Widget, public PG_EventObject
     
   protected:
 
-    Menu() throw(GuiMenuException) : PG_Widget(NULL, PG_Rect(0,0,640,480)) {}
+    Menu() : PG_Widget(NULL, PG_Rect(0,0,640,480)) {}
 
-    inline PG_Widget* getWidget(int id) throw(GuiMenuException)
+    inline PG_Widget* getWidget(int id)
     {
         return MenuManager::getWidgetById(id);
     }
