@@ -6,7 +6,6 @@
 #include <pgthemewidget.h>
 
 #include "Tools.h"
-#include "GuiException.h"
 #include "MenuIds.h"
 
 class Menu;
@@ -15,11 +14,9 @@ class MenuManager
 {
   public:
 
-    static void init(const char* layout, const char* theme)
-        throw(Exception);
+    static void init(const char* layout, const char* theme);
 
-    static void initScreen(bool fullScreen)
-        throw (GuiException);
+    static void initScreen(bool fullScreen);
 
     static void destroy();
 
@@ -29,18 +26,20 @@ class MenuManager
         return sm_instance;
     }
 
-    void changeTo(Menu* menu, bool background = true, bool overridePrevious = true);
-    void hideAll() throw(Exception);
+    void changeTo(Menu* menu,
+                  bool background = true,
+                  bool overridePrevious = true);
+    void hideAll();
     void redrawBackground();
 
-    static PG_Widget* getWidgetById(int id) throw(GuiMenuException);
+    static PG_Widget* getWidgetById(int id);
 
   protected:
 
     MenuManager();
     MenuManager(MenuManager&);
     virtual ~MenuManager();
-    void check(PG_Widget* w, int id) throw(GuiException);
+    void check(PG_Widget* w, int id);
 
     static MenuManager* sm_instance;
 
