@@ -14,12 +14,14 @@ class StatusBarMenu : public Menu
     void update();
 
   protected:
-    
+
+    void updateMessage();
     void updateScore();
     void updateLifes();
     void updateBonus();
     void updateFuel();
 
+    std::string m_message;
     unsigned m_score;
     unsigned m_lifes;
     unsigned m_lastBonusValue;
