@@ -3,7 +3,7 @@
 MENU_SINGLETON_INIT(Credits);
 
 //----------------------------------------------------------------------
-CreditsMenu::CreditsMenu() throw(GuiMenuException)
+CreditsMenu::CreditsMenu()
 {
   getWidget(ID_CREDITS_MENU_BACK)->SetEventObject(
     MSG_BUTTONCLICK, this, (MSG_CALLBACK_OBJ)&CreditsMenu::onReturn);
