@@ -3,7 +3,7 @@
 MENU_SINGLETON_INIT(Quit);
 
 //----------------------------------------------------------------------
-QuitMenu::QuitMenu() throw(GuiMenuException)
+QuitMenu::QuitMenu()
 {
   getWidget(ID_QUIT_MENU_DO)->SetEventObject(
       MSG_BUTTONCLICK, this, (MSG_CALLBACK_OBJ)&QuitMenu::onDo);
