@@ -82,7 +82,7 @@ class BarrierSurfaces : public SurfacesBase
         c() {} \
         ~c() {} \
         void onEntry(Barrier *barrier); \
-        void update(Barrier *barrier); \
+        void update(Barrier *barrier);  \
     }
 
 
@@ -101,7 +101,7 @@ class Barrier : public StaticDecorationBase,
 
         /**
          * This method is always called when changing to a new state.
-         * Its purpose is to switch the barrier's current surface.
+         * Its purpose is to change the barrier's m_activated member.
          */
         virtual void onEntry(Barrier *barrier) = 0;
 
@@ -111,11 +111,9 @@ class Barrier : public StaticDecorationBase,
     //------------------------------------------------------------------------
     DECLARE_UPDATE_STATE(Initial);
     DECLARE_UPDATE_STATE(InitialDelay);
-    DECLARE_UPDATE_STATE(PermanentActivation);
-    DECLARE_UPDATE_STATE(PermanentDeactivation);
     DECLARE_UPDATE_STATE(Activated);
     DECLARE_UPDATE_STATE(Deactivated);
-
+    DECLARE_UPDATE_STATE(DoNothing);
 
   public:
 
@@ -126,6 +124,7 @@ class Barrier : public StaticDecorationBase,
           public HVDecorationBase::InitializationData
     {
       public:
+        InitializationData();
         InitializationData(const XMLNode *magnetNode);
         ~InitializationData();
 
@@ -133,30 +132,30 @@ class Barrier : public StaticDecorationBase,
         bool activated;
     };
 
-
-    virtual ~Barrier();
+    //------------------------------------------------------------------------
+    Barrier(const InitializationData &init);
+    ~Barrier();
 
     //------------------------------------------------------------------------
     inline void activate()
     {
-        setUpdateState(PermanentActivation::getInstance());
+        m_activated = true;
     }
 
     inline void deactivate()
     {
-        setUpdateState(Deactivated::getInstance());
+        m_activated = false;
     }
 
     inline void toggle()
     {
-        if (m_updateState == Deactivated::getInstance())
-        {
-            setUpdateState(Activated::getInstance());
-        }
-        else
-        {
-            setUpdateState(Deactivated::getInstance());
-        }
+        m_activated = !m_activated;
+    }
+
+    //------------------------------------------------------------------------
+    inline bool isActivated() const
+    {
+        return m_activated;
     }
 
     //------------------------------------------------------------------------
@@ -169,26 +168,19 @@ class Barrier : public StaticDecorationBase,
     //------------------------------------------------------------------------
     void update();
 
+    //------------------------------------------------------------------------
+    void updateSurface();
+
     //------------------------------------------------------------------------
     static Barrier *create(const XMLNode *barrierNode);
 
-  protected:
-    //------------------------------------------------------------------------
-    Barrier(const InitializationData &init);
-
-    inline void updateSurface(bool activated)
-    {
-        setSurface(BarrierSurfaces::getInstance()->getSurface(
-                       getOrientation(), activated, getSize()));
-    }
-
-    //------------------------------------------------------------------------
-    static Barrier *create(const InitializationData &init);
-
   private:
     //------------------------------------------------------------------------
     DECLARE_OBJECT_VISITOR_API();
 
+    //------------------------------------------------------------------------
+    bool m_activated;
+
     //------------------------------------------------------------------------
     unsigned m_frameCounter;
 
