@@ -11,6 +11,7 @@ class CrateSurfaces : public SurfacesBase
 
   public:
 
+    //------------------------------------------------------------------------
     enum Type
     {
         T_SMALL = 0,
@@ -21,7 +22,8 @@ class CrateSurfaces : public SurfacesBase
         T_TOTAL_NUMBER = 5
     };
 
-    inline const SDL_Surface *getSurface(Type type) const
+    //------------------------------------------------------------------------
+    inline const SDL_Surface *getSurface(const Type type) const
     {
         assert(type >= 0);
         assert(type < T_TOTAL_NUMBER);
@@ -29,8 +31,21 @@ class CrateSurfaces : public SurfacesBase
         return m_crates[type];
     }
 
+    //------------------------------------------------------------------------
+    inline Uint16 getCrateWidth(const Type type) const
+    {
+        return getSurface(type)->w;
+    }
+
+    //------------------------------------------------------------------------
+    inline Uint16 getCrateHeight(const Type type) const
+    {
+        return getSurface(type)->h;
+    }
+
   private:
 
+    //------------------------------------------------------------------------
     /// All crate surfaces.
     SDL_Surface *m_crates[T_TOTAL_NUMBER];
 };
@@ -44,6 +59,7 @@ class Crate : public StaticDecorationBase
     class InitializationData : public StaticDecorationBase::InitializationData
     {
       public:
+        InitializationData();
         InitializationData(const XMLNode *crateNode);
         ~InitializationData();
 
@@ -55,8 +71,10 @@ class Crate : public StaticDecorationBase
 
 
     //------------------------------------------------------------------------
-    virtual ~Crate();
+    Crate(const InitializationData &init);
+    ~Crate();
 
+    //------------------------------------------------------------------------
     static Crate *create(const XMLNode *crateNode);
 
     inline CrateSurfaces::Type getType() const 
@@ -85,9 +103,8 @@ class Crate : public StaticDecorationBase
     //------------------------------------------------------------------------
     void update();
 
-  protected:
     //------------------------------------------------------------------------
-    Crate(const InitializationData &init);
+    void updateSurface();
 
   private:
     //------------------------------------------------------------------------
