@@ -27,12 +27,12 @@ class GrenadeSurfaces : public SingleSurfacesBase
       public: \
         c() {} \
         ~c() {} \
-        void onCreateExplosionParticles(const GrenadeBase *grenade) const; \
+        void onCreateExplosionParticles(const Grenade *grenade) const; \
     }
 
 
 //----------------------------------------------------------------------------
-class GrenadeBase : public MovingObjectBase
+class Grenade : public MovingObjectBase
 {
   public:
     //------------------------------------------------------------------------
@@ -53,7 +53,7 @@ class GrenadeBase : public MovingObjectBase
       public:
         virtual ~WarheadStrategy() {}
 
-        virtual void onCreateExplosionParticles(const GrenadeBase *grenade) const = 0;
+        virtual void onCreateExplosionParticles(const Grenade *grenade) const = 0;
 
         static WarheadStrategy *getStrategy(EnumWarheadStrategy s);
 
@@ -68,8 +68,8 @@ class GrenadeBase : public MovingObjectBase
   public:
 
     //------------------------------------------------------------------------
-    GrenadeBase(EnumWarheadStrategy warhead, const unsigned creatorId);
-    virtual ~GrenadeBase();
+    Grenade(EnumWarheadStrategy warhead, const unsigned creatorId);
+    virtual ~Grenade();
 
     //------------------------------------------------------------------------
     inline bool isExplode() const { return m_explode; }
@@ -77,6 +77,9 @@ class GrenadeBase : public MovingObjectBase
     //------------------------------------------------------------------------
     void update();
 
+    //------------------------------------------------------------------------
+    void updateSurface();
+
     //------------------------------------------------------------------------
     /**
      * Called via the CreateExplosionParticleConstVisitor.
@@ -86,7 +89,6 @@ class GrenadeBase : public MovingObjectBase
         m_warheadStrategy->onCreateExplosionParticles(this);
     }
 
-  protected:
     //------------------------------------------------------------------------
     inline void setLifeCount(unsigned lifeCount)
     {
@@ -108,12 +110,4 @@ class GrenadeBase : public MovingObjectBase
     WarheadStrategy *m_warheadStrategy;
 };
 
-//----------------------------------------------------------------------------
-class MortarGrenade : public GrenadeBase
-{
-  public:
-    MortarGrenade(MortarBase *creator, const MortarBarrel *barrel);
-    ~MortarGrenade();
-};
-
 #endif //GRENADE_H
