@@ -116,8 +116,8 @@ class MagnetBase : public StaticDecorationBase,
           public OrientatingDecorationBase::InitializationData
     {
       public:
+        InitializationData();
         InitializationData(const XMLNode *magnetNode);
-        
         ~InitializationData();
 
         unsigned wh;
@@ -130,9 +130,6 @@ class MagnetBase : public StaticDecorationBase,
     //------------------------------------------------------------------------
     virtual ~MagnetBase();
 
-    static MagnetBase *create(const XMLNode *magnetNode);
-
-
     //------------------------------------------------------------------------
     inline unsigned getSize() const
     {
@@ -149,6 +146,11 @@ class MagnetBase : public StaticDecorationBase,
         return m_distance;
     }
 
+    inline unsigned getCurrentFrame() const
+    {
+        return m_currentFrame;
+    }
+
     inline void setUpdateState(UpdateState *state)
     {
         m_updateState = state;
@@ -157,12 +159,18 @@ class MagnetBase : public StaticDecorationBase,
     //------------------------------------------------------------------------
     void update();
 
+    //------------------------------------------------------------------------
+    void updateSurface();
+
+    //------------------------------------------------------------------------
+    static MagnetBase *create(const InitializationData &init);
+    static MagnetBase *create(const XMLNode *magnetNode);
+
   protected:
+
     //------------------------------------------------------------------------
     MagnetBase(const InitializationData &init);
 
-    static MagnetBase *create(const InitializationData &init);
-
     //------------------------------------------------------------------------
     virtual void addGravityToPlayGround() const = 0;
     virtual void subGravityFromPlayGround() const = 0;
