@@ -61,6 +61,7 @@ class ParticleFountainBase : public StaticDecorationBase,
           public OrientatingDecorationBase::InitializationData
     {
       public:
+        InitializationData();
         InitializationData(const XMLNode *fountainNode);
         ~InitializationData();
 
@@ -73,7 +74,6 @@ class ParticleFountainBase : public StaticDecorationBase,
     //------------------------------------------------------------------------
     virtual ~ParticleFountainBase();
 
-    static ParticleFountainBase *create(const XMLNode *fountainNode);
 
     //------------------------------------------------------------------------
     inline const MATH_TOOLS::Vector &getParticleInitialVelocity() const
@@ -102,6 +102,13 @@ class ParticleFountainBase : public StaticDecorationBase,
     //------------------------------------------------------------------------
     void update();
 
+    //------------------------------------------------------------------------
+    void updateSurface();
+
+    //------------------------------------------------------------------------
+    static ParticleFountainBase *create(const InitializationData &init);
+    static ParticleFountainBase *create(const XMLNode *fountainNode);
+
   protected:
     //------------------------------------------------------------------------
     ParticleFountainBase(const InitializationData &init);
@@ -111,8 +118,6 @@ class ParticleFountainBase : public StaticDecorationBase,
         return m_particleInitialVelocity;
     }
 
-    static ParticleFountainBase *create(const InitializationData &init);
-
     unsigned m_frameCounter;
     unsigned m_createParticleCounter;
 
