@@ -38,7 +38,9 @@ class PlatformSurfaces : public SurfacesBase
         ET_BLUE = 14,
         ET_MAGENTA = 15,
 
-        ET_TOTAL_NUMBER = 16
+        ET_FUEL = 16,
+
+        ET_TOTAL_NUMBER = 17
     };
 
   private:
@@ -79,6 +81,9 @@ class PlatformSurfaces : public SurfacesBase
     const SDL_Surface *getSurface(EdgeType left, EdgeType right,
                                   unsigned frame, unsigned size);
 
+    //------------------------------------------------------------------------
+    Uint16 getPlatformHeight() const;
+
   private:
 
     //------------------------------------------------------------------------
@@ -109,6 +114,7 @@ class Platform : public StaticDecorationBase
     class InitializationData : public StaticDecorationBase::InitializationData
     {
       public:
+        InitializationData();
         InitializationData(const XMLNode *platformNode);
         ~InitializationData();
 
@@ -124,8 +130,10 @@ class Platform : public StaticDecorationBase
 
 
     //------------------------------------------------------------------------
-    virtual ~Platform();
+    Platform(const InitializationData &init);
+    ~Platform();
 
+    //------------------------------------------------------------------------
     static Platform *create(const XMLNode *platformNode);
 
     //------------------------------------------------------------------------
@@ -134,6 +142,30 @@ class Platform : public StaticDecorationBase
         return m_width;
     }
 
+    //------------------------------------------------------------------------
+    inline unsigned getCurrentFrame() const
+    {
+        return m_currentFrame;
+    }
+
+    //------------------------------------------------------------------------
+    inline PlatformSurfaces::EdgeType getLeftEdgeType() const 
+    {
+        return m_left;
+    }
+    
+    inline PlatformSurfaces::EdgeType getRightEdgeType() const 
+    {
+        return m_right;
+    }
+
+    //------------------------------------------------------------------------
+    inline bool isFuelPlatform() const
+    {
+        return m_fuel;
+    }
+
+    //------------------------------------------------------------------------
     inline const SDL_Rect &getLandingZone() const
     {
         return m_landingZone;
@@ -142,10 +174,11 @@ class Platform : public StaticDecorationBase
     //------------------------------------------------------------------------
     void update();
 
+    //------------------------------------------------------------------------
+    void updateSurface();
+
   protected:
     //------------------------------------------------------------------------
-    Platform(const InitializationData &init);
-
     /// Called by the constructor to initialize m_landingZone.
     void initLandingZone();
 
@@ -163,6 +196,8 @@ class Platform : public StaticDecorationBase
     PlatformSurfaces::EdgeType m_left;
     PlatformSurfaces::EdgeType m_right;
 
+    bool m_fuel;
+
     /// A one pixel high rectangle on top of the center platform tiles.
     SDL_Rect m_landingZone;
 };
