@@ -8,7 +8,7 @@ class TurretBarrel;
 class TurretBase;
 class Missile;
 class Tank;
-class GrenadeBase;
+class Grenade;
 
 #define PROJECTILE_VELOCITY 300
 
@@ -31,6 +31,9 @@ class ProjectileBase : public MovingObjectBase
     //------------------------------------------------------------------------
     void update();
 
+    //------------------------------------------------------------------------
+    void updateSurface();
+
   private:
     //------------------------------------------------------------------------
     DECLARE_OBJECT_VISITOR_API();
@@ -73,7 +76,7 @@ class TankProjectile : public ProjectileBase
 class GrenadeProjectile : public ProjectileBase
 {
   public:
-    GrenadeProjectile(const GrenadeBase *creator, int angle);
+    GrenadeProjectile(const Grenade *creator, int angle);
     ~GrenadeProjectile();
 };
 
