@@ -24,6 +24,7 @@ class SAMBatteryBase : public StaticDecorationBase,
           public OrientatingDecorationBase::InitializationData
     {
       public:
+        InitializationData();
         InitializationData(const XMLNode *samNode);
         ~InitializationData();
 
@@ -37,11 +38,16 @@ class SAMBatteryBase : public StaticDecorationBase,
     //------------------------------------------------------------------------
     virtual ~SAMBatteryBase();
 
-    static SAMBatteryBase *create(const XMLNode *samNode);
-
     //------------------------------------------------------------------------
     void update();
 
+    //------------------------------------------------------------------------
+    void updateSurface();
+
+    //------------------------------------------------------------------------
+    static SAMBatteryBase *create(const InitializationData &init);
+    static SAMBatteryBase *create(const XMLNode *samNode);
+
   protected:
     //------------------------------------------------------------------------
     SAMBatteryBase(const InitializationData &init);
@@ -50,9 +56,6 @@ class SAMBatteryBase : public StaticDecorationBase,
     virtual Missile *createMissile() const = 0;
     Missile *do_createMissile(Sint16 angle) const;
 
-    //------------------------------------------------------------------------
-    static SAMBatteryBase *create(const InitializationData &init);
-
     //------------------------------------------------------------------------
     unsigned m_frameDelay;
     unsigned m_frameCounter;
