@@ -10,7 +10,7 @@
 #include "ControllableObjectBase.h"
 
 class Crate;
-
+class Platform;
 
 //----------------------------------------------------------------------------
 class ShipSurfaces : public SurfacesBase
@@ -98,8 +98,12 @@ class Ship : public ControllableObjectBase
   public:
     //------------------------------------------------------------------------
     Ship(ShipSurfaces::Ship shipType);
+    Ship(unsigned id, ShipSurfaces::Ship shipType);
     virtual ~Ship();
 
+    /// Called by GameControlBase::Running.
+    void incFuel(unsigned increment, unsigned maximum);
+
     /// Called by GameControlBase::AddFuelToScore.
     bool decFuel(unsigned decrement);
 
@@ -137,6 +141,11 @@ class Ship : public ControllableObjectBase
 
 
     //------------------------------------------------------------------------
+    inline const Platform *getLandedPlatform() const
+    {
+        return m_platform;
+    }
+
     inline Uint16 getTipOffset() const
     {
         return m_tipOffset;
@@ -154,6 +163,11 @@ class Ship : public ControllableObjectBase
      */
     void resetPosition(Sint16 x, Sint16 y, bool landed);
 
+    //------------------------------------------------------------------------
+    inline ShipSurfaces::Ship getShipType() const
+    {
+        return m_shipType;
+    }
 
     //------------------------------------------------------------------------
     inline unsigned getRotationDegreesPerSecond() const { return 216; }
@@ -192,6 +206,9 @@ class Ship : public ControllableObjectBase
     /// True, if the ship shall fire a projectile.
     bool m_fire;
 
+    /// The platform where this ship has landed.
+    const Platform *m_platform;
+
     /// A list of crates loaded in the ship.
     Crates m_crates;
 
