@@ -213,6 +213,7 @@ class TurretBase : public StaticDecorationBase,
           public OrientatingDecorationBase::InitializationData
     {
       public:
+        InitializationData();
         InitializationData(const XMLNode *turretNode);
         ~InitializationData();
 
@@ -224,9 +225,14 @@ class TurretBase : public StaticDecorationBase,
     };
 
 
+    //------------------------------------------------------------------------
     virtual ~TurretBase();
 
-    static TurretBase *create(const XMLNode *turretNode);
+    //------------------------------------------------------------------------
+    inline TurretSurfaces::Turret getType() const
+    {
+        return m_type;
+    }
 
     /// Returns, whether the turret can fire to the given angle.
     bool isAngleInRange(int angle) const;
@@ -248,12 +254,18 @@ class TurretBase : public StaticDecorationBase,
     //------------------------------------------------------------------------
     void update();
 
+    //------------------------------------------------------------------------
+    void updateSurface();
+
+    //------------------------------------------------------------------------
+    static TurretBase *create(const InitializationData &init);
+    static TurretBase *create(const XMLNode *turretNode);
+
   protected:
     //------------------------------------------------------------------------
     TurretBase(const InitializationData &init);
 
-    static TurretBase *create(const InitializationData &init);
-
+    //------------------------------------------------------------------------
     Uint16 m_tipOffset;
 
   private:
@@ -261,6 +273,9 @@ class TurretBase : public StaticDecorationBase,
     DECLARE_OBJECT_VISITOR_API();
 
     //------------------------------------------------------------------------
+    /// The type of turret, needed to access the ShipSurfaces factory.
+    TurretSurfaces::Turret m_type;
+
     TurretBarrelList m_barrels;
 
     unsigned m_hitPoints;
