@@ -45,6 +45,12 @@ ObjectBase::~ObjectBase()
 // Implementation of DecorationBase.h
 //============================================================================
 
+//----------------------------------------------------------------------------
+DecorationBase::InitializationData::InitializationData()
+{
+    id = 0;
+}
+
 //----------------------------------------------------------------------------
 DecorationBase::InitializationData::InitializationData(const XMLNode *node)
 {
@@ -122,6 +128,10 @@ DecorationBase *DecorationBase::create(const XMLNode *decorationNode)
     {
         return Tank::create(decorationNode);
     }
+    else if (name == "thorn")
+    {
+        return Thorn::create(decorationNode);
+    }
     else if (name == "turret")
     {
         return TurretBase::create(decorationNode);
@@ -158,6 +168,13 @@ bool DecorationBase::canReachPlayerShip() const
 // Implementation of StaticDecorationBase.h
 //============================================================================
 
+//----------------------------------------------------------------------------
+StaticDecorationBase::InitializationData::InitializationData()
+{
+    x = 0;
+    y = 0;
+}
+
 //----------------------------------------------------------------------------
 StaticDecorationBase::InitializationData::InitializationData(const XMLNode *node)
         : DecorationBase::InitializationData(node)
@@ -190,6 +207,14 @@ StaticDecorationBase::~StaticDecorationBase()
 // Implementation of AnimatedDecorationBase.h
 //============================================================================
 
+//----------------------------------------------------------------------------
+AnimatedDecorationBase::InitializationData::InitializationData()
+{
+    on = 0;
+    off = 0;
+    delay = 0;
+}
+
 //----------------------------------------------------------------------------
 AnimatedDecorationBase::InitializationData::InitializationData(const XMLNode *node)
 {
@@ -224,6 +249,12 @@ AnimatedDecorationBase::~AnimatedDecorationBase()
 // Implementation of OrientatingDecorationBase.h
 //============================================================================
 
+//----------------------------------------------------------------------------
+OrientatingDecorationBase::InitializationData::InitializationData()
+{
+    orientation = O_TOP;
+}
+
 //----------------------------------------------------------------------------
 OrientatingDecorationBase::InitializationData::InitializationData(const XMLNode *node)
 {
@@ -276,6 +307,13 @@ OrientatingDecorationBase::~OrientatingDecorationBase()
 // Implementation of HVDecorationBase.h
 //============================================================================
 
+//----------------------------------------------------------------------------
+HVDecorationBase::InitializationData::InitializationData()
+{
+    orientation = O_HORIZONTAL;
+    wh = 0;
+}
+
 //----------------------------------------------------------------------------
 HVDecorationBase::InitializationData::InitializationData(const XMLNode *node)
 {
@@ -319,6 +357,11 @@ HVDecorationBase::~HVDecorationBase()
 // Implementation of MovingDecorationBase.h
 //============================================================================
 
+//----------------------------------------------------------------------------
+MovingDecorationBase::InitializationData::InitializationData()
+{
+}
+
 //----------------------------------------------------------------------------
 MovingDecorationBase::InitializationData::InitializationData(const XMLNode *node)
         : DecorationBase::InitializationData(node)
@@ -348,6 +391,13 @@ MovingDecorationBase::~MovingDecorationBase()
 // Implementation of Barriers.h
 //============================================================================
 
+//----------------------------------------------------------------------------
+Barrier::InitializationData::InitializationData()
+{
+    activatedPresent = false;
+    activated = false;
+}
+
 //----------------------------------------------------------------------------
 Barrier::InitializationData::InitializationData(const XMLNode *barrierNode)
         : StaticDecorationBase::InitializationData(barrierNode),
@@ -367,15 +417,14 @@ Barrier::InitializationData::~InitializationData()
 //----------------------------------------------------------------------------
 Barrier::Initial Barrier::Initial::sm_instance;
 Barrier::InitialDelay Barrier::InitialDelay::sm_instance;
-Barrier::PermanentActivation Barrier::PermanentActivation::sm_instance;
-Barrier::PermanentDeactivation Barrier::PermanentDeactivation::sm_instance;
 Barrier::Activated Barrier::Activated::sm_instance;
 Barrier::Deactivated Barrier::Deactivated::sm_instance;
+Barrier::DoNothing Barrier::DoNothing::sm_instance;
+
 
 //----------------------------------------------------------------------------
 void Barrier::Initial::onEntry(Barrier *barrier)
 {
-    barrier->updateSurface(false);
 }
 
 //----------------------------------------------------------------------------
@@ -389,7 +438,7 @@ void Barrier::Initial::update(Barrier *barrier)
     }
     else if (barrier->getOnInterval() == 0 || barrier->getOffInterval() == 0)
     {
-        state = PermanentActivation::getInstance();
+        state = DoNothing::getInstance();
     }
     else
     {
@@ -404,7 +453,6 @@ void Barrier::Initial::update(Barrier *barrier)
 //----------------------------------------------------------------------------
 void Barrier::InitialDelay::onEntry(Barrier *barrier)
 {
-    barrier->updateSurface(false);
 }
 
 //----------------------------------------------------------------------------
@@ -417,45 +465,22 @@ void Barrier::InitialDelay::update(Barrier *barrier)
         UpdateState *state = NULL;
         if (barrier->getOnInterval() == 0 || barrier->getOffInterval() == 0)
         {
-            state = PermanentActivation::getInstance();
+            state = DoNothing::getInstance();
         }
         else
         {
             state = Activated::getInstance();
         }
+
         barrier->setUpdateState(state);
     }
 }
 
 
-//----------------------------------------------------------------------------
-void Barrier::PermanentActivation::onEntry(Barrier *barrier)
-{
-    barrier->updateSurface(true);
-}
-
-//----------------------------------------------------------------------------
-void Barrier::PermanentActivation::update(Barrier *barrier)
-{
-}
-
-
-//----------------------------------------------------------------------------
-void Barrier::PermanentDeactivation::onEntry(Barrier *barrier)
-{
-    barrier->updateSurface(false);
-}
-
-//----------------------------------------------------------------------------
-void Barrier::PermanentDeactivation::update(Barrier *barrier)
-{
-}
-
-
 //----------------------------------------------------------------------------
 void Barrier::Activated::onEntry(Barrier *barrier)
 {
-    barrier->updateSurface(true);
+    barrier->activate();
 }
 
 //----------------------------------------------------------------------------
@@ -472,7 +497,7 @@ void Barrier::Activated::update(Barrier *barrier)
 //----------------------------------------------------------------------------
 void Barrier::Deactivated::onEntry(Barrier *barrier)
 {
-    barrier->updateSurface(false);
+    barrier->deactivate();
 }
 
 //----------------------------------------------------------------------------
@@ -486,24 +511,31 @@ void Barrier::Deactivated::update(Barrier *barrier)
 }
 
 
+//----------------------------------------------------------------------------
+void Barrier::DoNothing::onEntry(Barrier *barrier)
+{
+}
+
+//----------------------------------------------------------------------------
+void Barrier::DoNothing::update(Barrier *barrier)
+{
+}
+
+
 //----------------------------------------------------------------------------
 Barrier::Barrier(const InitializationData &init)
         : StaticDecorationBase(init),
           AnimatedDecorationBase(init),
           HVDecorationBase(init)
 {
+    m_activated = false;
+
     m_frameCounter = 0;
 
     if (init.activatedPresent)
     {
-        if (init.activated)
-        {
-            setUpdateState(PermanentActivation::getInstance());
-        }
-        else
-        {
-            setUpdateState(PermanentDeactivation::getInstance());
-        }
+        m_activated = init.activated;
+        setUpdateState(DoNothing::getInstance());
     }
     else
     {
@@ -529,6 +561,13 @@ void Barrier::update()
     m_updateState->update(this);
 }
 
+//----------------------------------------------------------------------------
+void Barrier::updateSurface()
+{
+    setSurface(BarrierSurfaces::getInstance()->getSurface(
+                   getOrientation(), m_activated, getSize()));
+}
+
 //----------------------------------------------------------------------------
 DECLARE_OBJECT_VISITOR_API_BODY(Barrier)
 
@@ -538,6 +577,12 @@ DECLARE_OBJECT_VISITOR_API_BODY(Barrier)
 // Implementation of BlackHole.h
 //============================================================================
 
+//----------------------------------------------------------------------------
+BlackHole::InitializationData::InitializationData()
+{
+    gravity = 0;
+}
+
 //----------------------------------------------------------------------------
 BlackHole::InitializationData::InitializationData(const XMLNode *blackHoleNode)
         : StaticDecorationBase::InitializationData(blackHoleNode)
@@ -555,8 +600,6 @@ BlackHole::InitializationData::~InitializationData()
 BlackHole::BlackHole(const InitializationData &init)
         : StaticDecorationBase(init)
 {
-    setSurface(BlackHoleSurfaces::getInstance()->getSurface());
-
     m_gravity = init.gravity;
 
     addGravityToPlayGround();
@@ -578,6 +621,12 @@ void BlackHole::update()
 {
 }
 
+//----------------------------------------------------------------------------
+void BlackHole::updateSurface()
+{
+    setSurface(BlackHoleSurfaces::getInstance()->getSurface());
+}
+
 //----------------------------------------------------------------------------
 void BlackHole::addGravityToPlayGround() const
 {
@@ -624,6 +673,15 @@ DECLARE_OBJECT_VISITOR_API_BODY(BlackHole)
 // Implementation of Crate.h
 //============================================================================
 
+//----------------------------------------------------------------------------
+Crate::InitializationData::InitializationData()
+{
+    hidden = false;
+    type = CrateSurfaces::T_SMALL;
+    score = 0;
+    amount = 0;
+}
+
 //----------------------------------------------------------------------------
 Crate::InitializationData::InitializationData(const XMLNode *crateNode)
         : StaticDecorationBase::InitializationData(crateNode)
@@ -670,15 +728,14 @@ Crate::Crate(const InitializationData &init)
         break;
     }
 
-    setSurface(CrateSurfaces::getInstance()->getSurface(m_type));
-
     // init contains the tile coordinates, where the crate shall lie.
     // Calculate the exact pixel position.
 
     Uint16 x = init.x * 16;
     Uint16 y = init.y * 16;
-    x += (16 - getPosition().w) / 2;
-    y += 16 - getPosition().h - 4;  // 4 is the height of the platform.
+    x += (16 - CrateSurfaces::getInstance()->getCrateWidth(m_type)) / 2;
+    y += 16 - CrateSurfaces::getInstance()->getCrateHeight(m_type)
+        - PlatformSurfaces::getInstance()->getPlatformHeight();
 
     setPosition(x, y);
 }
@@ -699,6 +756,12 @@ void Crate::update()
 {
 }
 
+//----------------------------------------------------------------------------
+void Crate::updateSurface()
+{
+    setSurface(CrateSurfaces::getInstance()->getSurface(m_type));
+}
+
 //----------------------------------------------------------------------------
 DECLARE_OBJECT_VISITOR_API_BODY(Crate)
 
@@ -708,6 +771,14 @@ DECLARE_OBJECT_VISITOR_API_BODY(Crate)
 // Implementation of Magnets.h
 //============================================================================
 
+//----------------------------------------------------------------------------
+MagnetBase::InitializationData::InitializationData()
+{
+    wh = 0;
+    strength = 0;
+    distance = 0;
+}
+
 //----------------------------------------------------------------------------
 MagnetBase::InitializationData::InitializationData(const XMLNode *magnetNode)
         : StaticDecorationBase::InitializationData(magnetNode),
@@ -786,12 +857,6 @@ void MagnetBase::PermanentActivation::update(MagnetBase *magnet)
     {
         magnet->m_frameDelay = 0;
         magnet->m_currentFrame = (magnet->m_currentFrame+1) % 4;
-
-        magnet->setSurface(
-            MagnetSurfaces::getInstance()->getSurface(
-                magnet->getOrientation(),
-                magnet->m_currentFrame,
-                magnet->getSize()));
     }
 }
 
@@ -830,9 +895,6 @@ MagnetBase::MagnetBase(const InitializationData &init)
     m_strength = init.strength;
     m_distance = init.distance;
 
-    setSurface(MagnetSurfaces::getInstance()->getSurface(
-                   getOrientation(), 0, getSize()));
-
     m_frameDelay = 0;
     m_currentFrame = 0;
     m_frameCounter = 0;
@@ -876,6 +938,13 @@ void MagnetBase::update()
     m_updateState->update(this);
 }
 
+//----------------------------------------------------------------------------
+void MagnetBase::updateSurface()
+{
+    setSurface(MagnetSurfaces::getInstance()->getSurface(
+                   getOrientation(), m_currentFrame, getSize()));
+}
+
 //----------------------------------------------------------------------------
 DECLARE_OBJECT_VISITOR_API_BODY(MagnetBase)
 
@@ -896,7 +965,7 @@ void TopMagnet::addGravityToPlayGround() const
 {
     for (Uint16 y=0; y<getDistance(); y++)
     {
-        for (Uint16 x=0; x<getPosition().w/16; x++)
+        for (Uint16 x=0; x<getSize()/16; x++)
         {
             GameInterface::getInstance()->addYGravityToPlayGround(
                 getPosition().x/16+x, getPosition().y/16+1+y, -getStrength());
@@ -909,7 +978,7 @@ void TopMagnet::subGravityFromPlayGround() const
 {
     for (Uint16 y=0; y<getDistance(); y++)
     {
-        for (Uint16 x=0; x<getPosition().w/16; x++)
+        for (Uint16 x=0; x<getSize()/16; x++)
         {
             GameInterface::getInstance()->addYGravityToPlayGround(
                 getPosition().x/16+x, getPosition().y/16+1+y, getStrength());
@@ -934,7 +1003,7 @@ void BottomMagnet::addGravityToPlayGround() const
 {
     for (Uint16 y=0; y<getDistance(); y++)
     {
-        for (Uint16 x=0; x<getPosition().w/16; x++)
+        for (Uint16 x=0; x<getSize()/16; x++)
         {
             GameInterface::getInstance()->addYGravityToPlayGround(
                 getPosition().x/16+x, getPosition().y/16-1-y, getStrength());
@@ -947,7 +1016,7 @@ void BottomMagnet::subGravityFromPlayGround() const
 {
     for (Uint16 y=0; y<getDistance(); y++)
     {
-        for (Uint16 x=0; x<getPosition().w/16; x++)
+        for (Uint16 x=0; x<getSize()/16; x++)
         {
             GameInterface::getInstance()->addYGravityToPlayGround(
                 getPosition().x/16+x, getPosition().y/16-1-y, -getStrength());
@@ -970,7 +1039,7 @@ LeftMagnet::~LeftMagnet()
 //----------------------------------------------------------------------------
 void LeftMagnet::addGravityToPlayGround() const
 {
-    for (Uint16 y=0; y<getPosition().h/16; y++)
+    for (Uint16 y=0; y<getSize()/16; y++)
     {
         for (Uint16 x=0; x<getDistance(); x++)
         {
@@ -983,7 +1052,7 @@ void LeftMagnet::addGravityToPlayGround() const
 //----------------------------------------------------------------------------
 void LeftMagnet::subGravityFromPlayGround() const
 {
-    for (Uint16 y=0; y<getPosition().h/16; y++)
+    for (Uint16 y=0; y<getSize()/16; y++)
     {
         for (Uint16 x=0; x<getDistance(); x++)
         {
@@ -1008,7 +1077,7 @@ RightMagnet::~RightMagnet()
 //----------------------------------------------------------------------------
 void RightMagnet::addGravityToPlayGround() const
 {
-    for (Uint16 y=0; y<getPosition().h/16; y++)
+    for (Uint16 y=0; y<getSize()/16; y++)
     {
         for (Uint16 x=0; x<getDistance(); x++)
         {
@@ -1021,7 +1090,7 @@ void RightMagnet::addGravityToPlayGround() const
 //----------------------------------------------------------------------------
 void RightMagnet::subGravityFromPlayGround() const
 {
-    for (Uint16 y=0; y<getPosition().h/16; y++)
+    for (Uint16 y=0; y<getSize()/16; y++)
     {
         for (Uint16 x=0; x<getDistance(); x++)
         {
@@ -1037,6 +1106,14 @@ void RightMagnet::subGravityFromPlayGround() const
 // Implementation of ParticleFountains.h
 //============================================================================
 
+//----------------------------------------------------------------------------
+ParticleFountainBase::InitializationData::InitializationData()
+{
+    speed = 0;
+    lifeTime = 0;
+    scatter = 0;
+}
+
 //----------------------------------------------------------------------------
 ParticleFountainBase::InitializationData::InitializationData(const XMLNode *fountainNode)
         : StaticDecorationBase::InitializationData(fountainNode),
@@ -1132,9 +1209,6 @@ ParticleFountainBase::ParticleFountainBase(const InitializationData &init)
           AnimatedDecorationBase(init),
           OrientatingDecorationBase(init)
 {
-    setSurface(
-        ParticleFountainSurfaces::getInstance()->getSurface(getOrientation()));
-
     m_particleSpeed = init.speed;
     m_particleLifeTime = init.lifeTime;
     m_particleScatter = init.scatter;
@@ -1182,6 +1256,13 @@ void ParticleFountainBase::update()
     m_updateState->update(this);
 }
 
+//----------------------------------------------------------------------------
+void ParticleFountainBase::updateSurface()
+{
+    setSurface(
+        ParticleFountainSurfaces::getInstance()->getSurface(getOrientation()));
+}
+
 //----------------------------------------------------------------------------
 DECLARE_OBJECT_VISITOR_API_BODY(ParticleFountainBase)
 
@@ -1243,6 +1324,15 @@ RightParticleFountain::~RightParticleFountain()
 // Implementation of Platform.h
 //============================================================================
 
+//----------------------------------------------------------------------------
+Platform::InitializationData::InitializationData()
+{
+    w = 0;
+
+    left = PlatformSurfaces::ET_NO_EDGE;
+    right = PlatformSurfaces::ET_NO_EDGE;
+}
+
 //----------------------------------------------------------------------------
 Platform::InitializationData::InitializationData(const XMLNode *platformNode)
         : StaticDecorationBase::InitializationData(platformNode)
@@ -1276,13 +1366,15 @@ PlatformSurfaces::EdgeType Platform::InitializationData::getEdgeType(
     if (color == "blue")  return PlatformSurfaces::ET_BLUE;
     if (color == "magenta")  return PlatformSurfaces::ET_MAGENTA;
 
+    if (color == "fuel")  return PlatformSurfaces::ET_FUEL;
+
     unsigned number = node->getUnsignedProperty(prop);
     if (number < 10)  return (PlatformSurfaces::EdgeType)number;
 
     throw XMLException(
         std::string("The value of the '").append(prop)
         .append("' attribute must be ")
-        .append("'red', 'yellow', 'green', 'cyan', 'blue', 'magenta', "
+        .append("'red', 'yellow', 'green', 'cyan', 'blue', 'magenta', 'fuel', "
                 "or a number between '0' and '9'"));
 }
 
@@ -1295,9 +1387,8 @@ Platform::Platform(const InitializationData &init)
 
     m_left = init.left;
     m_right = init.right;
-
-    setSurface(PlatformSurfaces::getInstance()->getSurface(
-                   m_left, m_right, 0, getWidth()));
+    m_fuel = (m_left == PlatformSurfaces::ET_FUEL ||
+              m_right == PlatformSurfaces::ET_FUEL);
 
     initLandingZone();
 
@@ -1322,18 +1413,10 @@ void Platform::initLandingZone()
 {
     // The ship cannot land on the border tiles.
     m_landingZone.x = getPosition().x + 16;
-    m_landingZone.w = getPosition().w - 32;
+    m_landingZone.w = m_width - 32;
 
-    Sint16 y;
-    for (y = getPosition().h - 1; y >= 0; y--)
-    {
-        if (!SDL_TOOLS::getPixel(getSurface(), 16, y))
-        {
-            break;
-        }
-    }
-
-    m_landingZone.y = getPosition().y + y;
+    m_landingZone.y = getPosition().y + 15
+        - PlatformSurfaces::getInstance()->getPlatformHeight();
     m_landingZone.h = 1;
 }
 
@@ -1344,12 +1427,16 @@ void Platform::update()
     {
         m_frameCounter = 0;
         m_currentFrame = (m_currentFrame+1) % 2;
-
-        setSurface(PlatformSurfaces::getInstance()->getSurface(
-                       m_left, m_right, m_currentFrame, getWidth()));
     }
 }
 
+//----------------------------------------------------------------------------
+void Platform::updateSurface()
+{
+    setSurface(PlatformSurfaces::getInstance()->getSurface(
+                   m_left, m_right, m_currentFrame, getWidth()));
+}
+
 //----------------------------------------------------------------------------
 DECLARE_OBJECT_VISITOR_API_BODY(Platform)
 
@@ -1359,6 +1446,15 @@ DECLARE_OBJECT_VISITOR_API_BODY(Platform)
 // Implementation of SAMBatteries.h
 //============================================================================
 
+//----------------------------------------------------------------------------
+SAMBatteryBase::InitializationData::InitializationData()
+{
+    delay = 0;
+    missileFuel = 0;
+    missileHeadingStrategy = Missile::HS_DIRECT;
+    missileWarheadStrategy = Missile::WH_NORMAL;
+}
+
 //----------------------------------------------------------------------------
 SAMBatteryBase::InitializationData::InitializationData(const XMLNode *samNode)
         : StaticDecorationBase::InitializationData(samNode),
@@ -1402,9 +1498,6 @@ SAMBatteryBase::SAMBatteryBase(const InitializationData &init)
         : StaticDecorationBase(init),
           OrientatingDecorationBase(init)
 {
-    setSurface(
-        SAMBatterySurfaces::getInstance()->getSurface(getOrientation()));
-
     m_frameDelay = init.delay * SDLFrameRate::getFrameRate();
     m_frameCounter = 0;
 
@@ -1457,6 +1550,13 @@ void SAMBatteryBase::update()
     }
 }
 
+//----------------------------------------------------------------------------
+void SAMBatteryBase::updateSurface()
+{
+    setSurface(
+        SAMBatterySurfaces::getInstance()->getSurface(getOrientation()));
+}
+
 //----------------------------------------------------------------------------
 Missile *SAMBatteryBase::do_createMissile(Sint16 angle) const
 {
@@ -1583,6 +1683,11 @@ void RightSAMBattery::do_setInitialMissilePosition(Missile *m) const
 // Implementation of Switch.h
 //============================================================================
 
+//----------------------------------------------------------------------------
+SwitchBase::InitializationData::InitializationData()
+{
+}
+
 //----------------------------------------------------------------------------
 SwitchBase::InitializationData::InitializationData(const XMLNode *switchNode)
         : StaticDecorationBase::InitializationData(switchNode),
@@ -1604,8 +1709,6 @@ SwitchBase::SwitchBase(const InitializationData &init)
         : StaticDecorationBase(init),
           OrientatingDecorationBase(init)
 {
-    setSurface(SwitchSurfaces::getInstance()->getSurface(getOrientation()));
-
     m_objectIds = init.objectIds;
 }
 
@@ -1654,6 +1757,12 @@ void SwitchBase::update()
 {
 }
 
+//----------------------------------------------------------------------------
+void SwitchBase::updateSurface()
+{
+    setSurface(SwitchSurfaces::getInstance()->getSurface(getOrientation()));
+}
+
 //----------------------------------------------------------------------------
 DECLARE_OBJECT_VISITOR_API_BODY(SwitchBase)
 
@@ -1703,6 +1812,129 @@ RightSwitch::~RightSwitch()
 
 
 
+//============================================================================
+// Implementation of Thorns.h
+//============================================================================
+
+//----------------------------------------------------------------------------
+Thorn::InitializationData::InitializationData()
+{
+    wh = 0;
+}
+
+//----------------------------------------------------------------------------
+Thorn::InitializationData::InitializationData(const XMLNode *thornNode)
+        : StaticDecorationBase::InitializationData(thornNode),
+          AnimatedDecorationBase::InitializationData(thornNode),
+          OrientatingDecorationBase::InitializationData(thornNode)
+{
+    wh = 0;
+    switch (orientation)
+    {
+    case O_TOP:
+    case O_BOTTOM:
+        wh = thornNode->getUnsignedProperty("h");
+        break;
+
+    case O_LEFT:
+    case O_RIGHT:
+        wh = thornNode->getUnsignedProperty("w");
+        break;
+    }
+
+    // Modify the x/y position, since the x- and y-property
+    // refer to the position of the thorn's base.
+    switch (orientation)
+    {
+    case O_BOTTOM:
+        y -= wh-1;
+        break;
+
+    case O_RIGHT:
+        x -= wh-1;
+        break;
+
+    default:
+        break;
+    }
+}
+
+//----------------------------------------------------------------------------
+Thorn::InitializationData::~InitializationData()
+{
+}
+
+
+//----------------------------------------------------------------------------
+Thorn::Thorn(const InitializationData &init)
+        : StaticDecorationBase(init),
+          AnimatedDecorationBase(init),
+          OrientatingDecorationBase(init)
+{
+    m_size = 0;
+    m_tileSize = init.wh;
+    m_maxSize = (init.wh-1)*16;
+    m_sizeGoal = m_maxSize;
+
+    m_frameDelay = 1;
+    m_frameCounter = 0;
+}
+
+//----------------------------------------------------------------------------
+Thorn::~Thorn()
+{
+}
+
+//----------------------------------------------------------------------------
+Thorn *Thorn::create(const XMLNode *thornNode)
+{
+    return new Thorn(InitializationData(thornNode));
+}
+
+//----------------------------------------------------------------------------
+void Thorn::update()
+{
+    if (++m_frameCounter == m_frameDelay)
+    {
+        m_frameCounter = 0;
+
+        if (m_sizeGoal == 0)
+        {
+            if (m_size > m_sizeGoal)
+            {
+                --m_size;
+            }
+            else
+            {
+                m_sizeGoal = m_maxSize;
+            }
+        }
+        else
+        {
+            if (m_size < m_sizeGoal)
+            {
+                ++m_size;
+            }
+            else
+            {
+                m_sizeGoal = 0;
+            }
+        }
+    }
+}
+
+//----------------------------------------------------------------------------
+void Thorn::updateSurface()
+{
+    setSurface(ThornSurfaces::getInstance()->getSurface(
+                   getOrientation(), m_tileSize, m_size));
+}
+
+//----------------------------------------------------------------------------
+DECLARE_OBJECT_VISITOR_API_BODY(Thorn)
+
+
+
 //============================================================================
 // Implementation of Turrets.h
 //============================================================================
@@ -1874,6 +2106,13 @@ void TurretBase::BarrelVisitor::do_visit(const XMLNode *n)
 }
 
 
+//----------------------------------------------------------------------------
+TurretBase::InitializationData::InitializationData()
+{
+    type = TurretSurfaces::T_TUBE;
+    hitPoints = 0;
+}
+
 //----------------------------------------------------------------------------
 TurretBase::InitializationData::InitializationData(const XMLNode *turretNode)
         : StaticDecorationBase::InitializationData(turretNode),
@@ -1977,11 +2216,8 @@ TurretBase::TurretBase(const InitializationData &init)
         : StaticDecorationBase(init),
           OrientatingDecorationBase(init)
 {
-    setSurface(TurretSurfaces::getInstance()->getSurface(
-                   getOrientation(), init.type));
-
+    m_type = init.type;
     m_tipOffset = TurretSurfaces::getInstance()->getTipOffset(init.type);
-
     m_hitPoints = init.hitPoints;
 }
 
@@ -2042,6 +2278,13 @@ void TurretBase::update()
     }
 }
 
+//----------------------------------------------------------------------------
+void TurretBase::updateSurface()
+{
+    setSurface(TurretSurfaces::getInstance()->getSurface(
+                   getOrientation(), getType()));
+}
+
 //----------------------------------------------------------------------------
 bool TurretBase::isAngleInRange(int angle) const
 {
@@ -2185,9 +2428,9 @@ MortarBarrel::InitializationData::InitializationData(const XMLNode *barrelNode)
 
     const std::string &warhead = barrelNode->getStringProperty("warhead");
     if (warhead == "none")
-        grenadeWarheadStrategy = GrenadeBase::WH_NONE;
+        grenadeWarheadStrategy = Grenade::WH_NONE;
     else if (warhead == "starburst")
-        grenadeWarheadStrategy = GrenadeBase::WH_STARBURST;
+        grenadeWarheadStrategy = Grenade::WH_STARBURST;
     else
         throw XMLException(
             "The value of the 'warhead' attribute must be "
@@ -2226,7 +2469,7 @@ MortarBarrel::UpdateStrategy *MortarBarrel::UpdateStrategy::get(EnumUpdateStrate
 void MortarBarrel::Fixed::update(MortarBase *mortar, MortarBarrel *barrel)
 {
     ObjectRepository::getInstance()->addObject(
-        new MortarGrenade(mortar, barrel));
+        barrel->createGrenade(mortar));
 }
 
 //----------------------------------------------------------------------------
@@ -2234,7 +2477,7 @@ void MortarBarrel::Random::update(MortarBase *mortar, MortarBarrel *barrel)
 {
     barrel->setAngle(myRand(180) - 90);
     ObjectRepository::getInstance()->addObject(
-        new MortarGrenade(mortar, barrel));
+        barrel->createGrenade(mortar));
 }
 
 //----------------------------------------------------------------------------
@@ -2254,7 +2497,7 @@ void MortarBarrel::Smart::update(MortarBase *mortar, MortarBarrel *barrel)
     {
         barrel->setAngle(angle);
         ObjectRepository::getInstance()->addObject(
-            new MortarGrenade(mortar, barrel));
+            barrel->createGrenade(mortar));
     }
 }
 
@@ -2300,6 +2543,46 @@ void MortarBarrel::update(MortarBase *mortar)
     }
 }
 
+//----------------------------------------------------------------------------
+Grenade *MortarBarrel::createGrenade(MortarBase *mortar) const
+{
+    Grenade *grenade =
+        new Grenade(getGrenadeWarheadStrategy(), mortar->getId());
+
+    // Set the initial position.
+    Sint16 x, y;
+    switch (mortar->getTipPosition(x, y))
+    {
+    case OrientatingDecorationBase::O_TOP:
+        x -= grenade->getPosition().w / 2;
+        break;
+    case OrientatingDecorationBase::O_BOTTOM:
+        x -= grenade->getPosition().w / 2;
+        y -= grenade->getPosition().h;
+        break;
+    case OrientatingDecorationBase::O_LEFT:
+        y -= grenade->getPosition().h / 2;
+        break;
+    case OrientatingDecorationBase::O_RIGHT:
+        x -= grenade->getPosition().w;
+        y -= grenade->getPosition().h / 2;
+        break;
+    }
+
+    grenade->setPosition(x, y);
+
+    // Set the initial velocity.
+    grenade->getFineVelocity().setExponential(
+        1.0 * getGrenadeSpeed(),
+        1.0 * (mortar->getCenterAngle() + getAngle()));
+
+    grenade->setLifeCount(
+        getGrenadeExploderDelay() * SDLFrameRate::getFrameRate() / 10);
+
+
+    return grenade;
+}
+
 
 //----------------------------------------------------------------------------
 void MortarBase::BarrelVisitor::do_visit(const XMLProperty *a)
@@ -2320,6 +2603,12 @@ void MortarBase::BarrelVisitor::do_visit(const XMLNode *n)
 }
 
 
+//----------------------------------------------------------------------------
+MortarBase::InitializationData::InitializationData()
+{
+    hitPoints = 0;
+}
+
 //----------------------------------------------------------------------------
 MortarBase::InitializationData::InitializationData(const XMLNode *mortarNode)
         : StaticDecorationBase::InitializationData(mortarNode),
@@ -2339,9 +2628,6 @@ MortarBase::MortarBase(const InitializationData &init)
         : StaticDecorationBase(init),
           OrientatingDecorationBase(init)
 {
-    setSurface(TurretSurfaces::getInstance()->getSurface(
-                   getOrientation(), TurretSurfaces::T_BIGTUBE));
-
     m_tipOffset =
         TurretSurfaces::getInstance()->getTipOffset(TurretSurfaces::T_BIGTUBE);
 
@@ -2399,6 +2685,13 @@ void MortarBase::update()
     }
 }
 
+//----------------------------------------------------------------------------
+void MortarBase::updateSurface()
+{
+    setSurface(TurretSurfaces::getInstance()->getSurface(
+                   getOrientation(), TurretSurfaces::T_BIGTUBE));
+}
+
 //----------------------------------------------------------------------------
 bool MortarBase::isAngleInRange(int angle) const
 {
@@ -2574,6 +2867,12 @@ void Grinder::WayPointVisitor::do_visit(const XMLNode *n)
 }
 
 
+//----------------------------------------------------------------------------
+Grinder::InitializationData::InitializationData()
+{
+    velocity = 0;
+}
+
 //----------------------------------------------------------------------------
 Grinder::InitializationData::InitializationData(const XMLNode *grinderNode)
         : MovingDecorationBase::InitializationData(grinderNode)
@@ -2594,8 +2893,6 @@ Grinder::Grinder(const InitializationData &init) : MovingDecorationBase(init)
     m_currentFrame = 0;
     m_frameCounter = 0;
 
-    setSurface(GrinderSurfaces::getInstance()->getSurface(m_currentFrame));
-
     m_velocity = init.velocity;
 }
 
@@ -2625,7 +2922,7 @@ void Grinder::initVelocity()
 //----------------------------------------------------------------------------
 Grinder *Grinder::create(const XMLNode *grinderNode)
 {
-    Grinder *grinder = create(InitializationData(grinderNode));
+    Grinder *grinder = new Grinder(InitializationData(grinderNode));
 
     WayPointVisitor v(grinder);
     grinderNode->accept(v);
@@ -2644,13 +2941,6 @@ Grinder *Grinder::create(const XMLNode *grinderNode)
     return grinder;
 }
 
-//----------------------------------------------------------------------------
-Grinder *Grinder::create(const InitializationData &init)
-{
-    return new Grinder(init);
-}
-
-
 //----------------------------------------------------------------------------
 void Grinder::update()
 {
@@ -2688,11 +2978,16 @@ void Grinder::update()
             m_currentFrame = SURFACES_ROTATION_STEPS;
         }
 
-        setSurface(
-            GrinderSurfaces::getInstance()->getSurface(--m_currentFrame));
+        --m_currentFrame;
     }
 }
 
+//----------------------------------------------------------------------------
+void Grinder::updateSurface()
+{
+    setSurface(GrinderSurfaces::getInstance()->getSurface(m_currentFrame));
+}
+
 //----------------------------------------------------------------------------
 DECLARE_OBJECT_VISITOR_API_BODY(Grinder)
 
@@ -2789,6 +3084,17 @@ void Tank::WaitForMoving::update(Tank *tank)
 }
 
 
+//----------------------------------------------------------------------------
+Tank::InitializationData::InitializationData()
+{
+    x = 0;
+    y = 0;
+    w = 0;
+    hitPoints = 0;
+    speed = 0;
+    aimStrategy = AS_RANDOM;
+}
+
 //----------------------------------------------------------------------------
 Tank::InitializationData::InitializationData(const XMLNode *tankNode)
         : MovingDecorationBase::InitializationData(tankNode)
@@ -2817,8 +3123,6 @@ Tank::InitializationData::~InitializationData()
 //----------------------------------------------------------------------------
 Tank::Tank(const InitializationData &init) : MovingDecorationBase(init)
 {
-    setSurface(TankSurfaces::getInstance()->getSurface());
-
     m_x = init.x;
     m_y = init.y;
     m_w = init.w;
@@ -2841,13 +3145,7 @@ Tank::~Tank()
 //----------------------------------------------------------------------------
 Tank *Tank::create(const XMLNode *tankNode)
 {
-    return create(InitializationData(tankNode));
-}
-
-//----------------------------------------------------------------------------
-Tank *Tank::create(const InitializationData &init)
-{
-    return new Tank(init);
+    return new Tank(InitializationData(tankNode));
 }
 
 //----------------------------------------------------------------------------
@@ -2887,12 +3185,17 @@ void Tank::initWaitForMoving()
     setUpdateState(WaitForMoving::getInstance());
 }
 
-
 //----------------------------------------------------------------------------
 void Tank::update()
 {
     m_updateState->update(this);
 }
 
+//----------------------------------------------------------------------------
+void Tank::updateSurface()
+{
+    setSurface(TankSurfaces::getInstance()->getSurface());
+}
+
 //----------------------------------------------------------------------------
 DECLARE_OBJECT_VISITOR_API_BODY(Tank)
