@@ -144,7 +144,6 @@ void ControllableObjectBase::updateRotation()
     assert(m_fineAngle >= 0.0 && m_fineAngle < 360.0);
 
     m_angle = (unsigned)rint(m_fineAngle) / SURFACES_ROTATION_ANGLE;
-    setSurface(getRotationSurface(m_angle));
 
     if (m_rotation == ROT_ALIGN && m_angle == SURFACES_ROTATION_STEPS / 2)
     {
@@ -200,6 +199,12 @@ void ControllableObjectBase::updateVelocityAndPosition()
     updatePosition();
 }
 
+//----------------------------------------------------------------------------
+void ControllableObjectBase::updateSurface()
+{
+    setSurface(getRotationSurface(m_angle));
+}
+
 
 
 //============================================================================
@@ -394,8 +399,9 @@ Missile::Missile(EnumHeadingStrategy heading,
     m_mass = 20;
     m_thrust = true;
 
+    // @todo: The setSurface() call shouldn't be here.
+    // But it's currently needed for the internals of initBottomPixels().
     setSurface(getRotationSurface(SURFACES_ROTATION_STEPS / 2));
-
     initBottomPixels();
 
     m_headingStrategy = HeadingStrategy::getStrategy(heading);
@@ -509,6 +515,7 @@ void Ship::Landed::update(Ship *s)
         // If the thrusters are enabled, raise the ship by one pixel,
         // so the next update won't detect a landing again.
 
+        s->m_platform = NULL;
         s->getFinePosition().subY(1.0);
         s->updatePosition();
         s->setUpdateState(Flying::getInstance());
@@ -540,6 +547,8 @@ void Ship::Flying::update(Ship *s)
         if (s->getFineVelocity().getY() < SHIP_MIN_LANDING_VELOCITY)
         {
             // We are landing.
+            assert(s->m_platform == NULL);
+            s->m_platform = platform;
             s->getFineVelocity().set(0.0, 0.0);
             s->setUpdateState(Landed::getInstance());
 
@@ -571,20 +580,47 @@ Ship::Ship(ShipSurfaces::Ship shipType) : ControllableObjectBase(0)
     m_mass = 100;
     m_fire = false;
 
-    setSurface(getRotationSurface(SURFACES_ROTATION_STEPS / 2));
     m_tipOffset = ShipSurfaces::getInstance()->getTipOffset(m_shipType);
 
+    // @todo: The setSurface() call shouldn't be here.
+    // But it's currently needed for the internals of initBottomPixels().
+    setSurface(getRotationSurface(SURFACES_ROTATION_STEPS / 2));
     initBottomPixels();
 
     setUpdateState(Flying::getInstance());
 }
 
 //----------------------------------------------------------------------------
-Ship::~Ship()
+Ship::Ship(unsigned id, ShipSurfaces::Ship shipType)
+        : ControllableObjectBase(id)
 {
+    m_shipType = shipType;
+    m_mass = 0;
+    m_fire = false;
+    m_platform = NULL;
+    m_tipOffset = 0;
+
     setUpdateState(NULL);
 }
 
+//----------------------------------------------------------------------------
+Ship::~Ship()
+{
+    m_platform = NULL;
+
+    setUpdateState(NULL);
+}
+
+
+//----------------------------------------------------------------------------
+void Ship::incFuel(unsigned increment, unsigned maximum)
+{
+    m_fuel += increment;
+    if (m_fuel > maximum)
+    {
+        m_fuel = maximum;
+    }
+}
 
 //----------------------------------------------------------------------------
 bool Ship::decFuel(unsigned decrement)
@@ -680,8 +716,11 @@ void Ship::resetPosition(Sint16 x, Sint16 y, bool landed)
     updateRotation();
 
     setThrust(false);
-}
+    m_platform = NULL;
 
+    // Needed to reset the surface itself.
+    updateSurface();
+}
 
 
 //----------------------------------------------------------------------------
@@ -728,8 +767,6 @@ ParticleBase::ParticleBase(const ObjectBase *creator)
     m_gradient = false;
     m_gradientFineIndex = 0;
     m_gradientFineIndexIncrement = 0;
-
-    updateSurface();
 }
 
 //----------------------------------------------------------------------------
@@ -745,8 +782,6 @@ void ParticleBase::setGradient(unsigned fineSweepSpeed)
     m_gradientFineIndex =
         myRand(ParticleSurfaces::getInstance()->getGradientSize() / 16);
     m_gradientFineIndexIncrement = fineSweepSpeed/2 + (myRand(fineSweepSpeed));
-
-    updateSurface();
 }
 
 //----------------------------------------------------------------------------
@@ -924,7 +959,6 @@ void FountainParticle::init()
 ProjectileBase::ProjectileBase(const unsigned creatorId)
         : MovingObjectBase(creatorId)
 {
-    setSurface(ProjectileSurfaces::getInstance()->getSurface());
 }
 
 //----------------------------------------------------------------------------
@@ -943,6 +977,12 @@ void ProjectileBase::update()
     updatePosition();
 }
 
+//----------------------------------------------------------------------------
+void ProjectileBase::updateSurface()
+{
+    setSurface(ProjectileSurfaces::getInstance()->getSurface());
+}
+
 //----------------------------------------------------------------------------
 DECLARE_OBJECT_VISITOR_API_BODY(ProjectileBase)
 
@@ -994,13 +1034,16 @@ TurretProjectile::TurretProjectile(const TurretBase *turret,
     case OrientatingDecorationBase::O_TOP:
         x -= getPosition().w / 2;
         break;
+
     case OrientatingDecorationBase::O_BOTTOM:
         x -= getPosition().w / 2;
         y -= getPosition().h;
         break;
+
     case OrientatingDecorationBase::O_LEFT:
         y -= getPosition().h / 2;
         break;
+
     case OrientatingDecorationBase::O_RIGHT:
         x -= getPosition().w;
         y -= getPosition().h / 2;
@@ -1075,7 +1118,7 @@ TankProjectile::~TankProjectile()
 
 
 //----------------------------------------------------------------------------
-GrenadeProjectile::GrenadeProjectile(const GrenadeBase *grenade, int angle)
+GrenadeProjectile::GrenadeProjectile(const Grenade *grenade, int angle)
         : ProjectileBase(grenade->getCreatorId())
 {
     // Set the initial position.
@@ -1107,11 +1150,11 @@ GrenadeProjectile::~GrenadeProjectile()
 //============================================================================
 
 //----------------------------------------------------------------------------
-GrenadeBase::NoWarheadStrategy GrenadeBase::NoWarheadStrategy::sm_instance;
-GrenadeBase::StarBurstWarheadStrategy GrenadeBase::StarBurstWarheadStrategy::sm_instance;
+Grenade::NoWarheadStrategy Grenade::NoWarheadStrategy::sm_instance;
+Grenade::StarBurstWarheadStrategy Grenade::StarBurstWarheadStrategy::sm_instance;
 
 //----------------------------------------------------------------------------
-GrenadeBase::WarheadStrategy *GrenadeBase::WarheadStrategy::getStrategy(
+Grenade::WarheadStrategy *Grenade::WarheadStrategy::getStrategy(
     EnumWarheadStrategy strategy)
 {
     switch (strategy)
@@ -1126,12 +1169,12 @@ GrenadeBase::WarheadStrategy *GrenadeBase::WarheadStrategy::getStrategy(
 }
 
 //----------------------------------------------------------------------------
-void GrenadeBase::NoWarheadStrategy::onCreateExplosionParticles(const GrenadeBase *missile) const
+void Grenade::NoWarheadStrategy::onCreateExplosionParticles(const Grenade *grenade) const
 {
 }
 
 //----------------------------------------------------------------------------
-void GrenadeBase::StarBurstWarheadStrategy::onCreateExplosionParticles(const GrenadeBase *grenade) const
+void Grenade::StarBurstWarheadStrategy::onCreateExplosionParticles(const Grenade *grenade) const
 {
     // If the grenade crashed, no projectiles shall be created.
 
@@ -1147,26 +1190,23 @@ void GrenadeBase::StarBurstWarheadStrategy::onCreateExplosionParticles(const Gre
 
 
 //----------------------------------------------------------------------------
-GrenadeBase::GrenadeBase(EnumWarheadStrategy warhead,
-                         const unsigned creatorId)
+Grenade::Grenade(EnumWarheadStrategy warhead, const unsigned creatorId)
         : MovingObjectBase(creatorId)
 {
     m_lifeCount = 0;
     m_explode = false;
 
-    setSurface(GrenadeSurfaces::getInstance()->getSurface());
-
     m_warheadStrategy = WarheadStrategy::getStrategy(warhead);
 }
 
 //----------------------------------------------------------------------------
-GrenadeBase::~GrenadeBase()
+Grenade::~Grenade()
 {
     m_warheadStrategy = NULL;
 }
 
 //----------------------------------------------------------------------------
-void GrenadeBase::update()
+void Grenade::update()
 {
     GameInterface *gameInterface = GameInterface::getInstance();
 
@@ -1195,45 +1235,10 @@ void GrenadeBase::update()
 }
 
 //----------------------------------------------------------------------------
-DECLARE_OBJECT_VISITOR_API_BODY(GrenadeBase)
-
-
-//----------------------------------------------------------------------------
-MortarGrenade::MortarGrenade(MortarBase *mortar, const MortarBarrel *barrel)
-        : GrenadeBase(barrel->getGrenadeWarheadStrategy(), mortar->getId())
+void Grenade::updateSurface()
 {
-    // Set the initial position.
-    Sint16 x, y;
-    switch (mortar->getTipPosition(x, y))
-    {
-    case OrientatingDecorationBase::O_TOP:
-        x -= getPosition().w / 2;
-        break;
-    case OrientatingDecorationBase::O_BOTTOM:
-        x -= getPosition().w / 2;
-        y -= getPosition().h;
-        break;
-    case OrientatingDecorationBase::O_LEFT:
-        y -= getPosition().h / 2;
-        break;
-    case OrientatingDecorationBase::O_RIGHT:
-        x -= getPosition().w;
-        y -= getPosition().h / 2;
-        break;
-    }
-
-    setPosition(x, y);
-
-    // Set the initial velocity.
-    getFineVelocity().setExponential(
-        1.0 * barrel->getGrenadeSpeed(),
-        1.0 * (mortar->getCenterAngle() + barrel->getAngle()));
-
-    setLifeCount(
-        barrel->getGrenadeExploderDelay() * SDLFrameRate::getFrameRate() / 10);
+    setSurface(GrenadeSurfaces::getInstance()->getSurface());
 }
 
 //----------------------------------------------------------------------------
-MortarGrenade::~MortarGrenade()
-{
-}
+DECLARE_OBJECT_VISITOR_API_BODY(Grenade)
