@@ -40,7 +40,7 @@ void HasCrateForShipConstVisitor::do_visit(const Crate *c)
 
 
 //----------------------------------------------------------------------------
-void CreateExplosionParticleConstVisitor::do_visit(const GrenadeBase *g)
+void CreateExplosionParticleConstVisitor::do_visit(const Grenade *g)
 {
     do_createExplosionParticles(g, 15);
     g->onCreateExplosionParticles();
@@ -114,7 +114,7 @@ void CreateExplosionParticleConstVisitor::do_createExplosionParticles(
 
 
 //----------------------------------------------------------------------------
-void InitializeExplosionParticleConstVisitor::do_visit(const GrenadeBase *g)
+void InitializeExplosionParticleConstVisitor::do_visit(const Grenade *g)
 {
     m_particle->setLifeCount(SDLFrameRate::getFrameRate() - myRand(64));
     m_particle->setGravity();
