@@ -23,6 +23,7 @@ void SurfacesBase::init()
     BarrierSurfaces::init();
     SAMBatterySurfaces::init();
     SwitchSurfaces::init();
+    ThornSurfaces::init();
 
     CrateSurfaces::init();
     GrinderSurfaces::init();
@@ -48,6 +49,7 @@ void SurfacesBase::destroy()
     GrinderSurfaces::destroy();
     CrateSurfaces::destroy();
 
+    ThornSurfaces::destroy();
     SwitchSurfaces::destroy();
     SAMBatterySurfaces::destroy();
     BarrierSurfaces::destroy();
@@ -926,7 +928,6 @@ void PlatformSurfaces::init()
     sm_instance = new PlatformSurfaces();
     char file[1024];
 
-    // Load the beacon edge tiles.
     static const char *color[] =
     {
         "red", "yellow", "green", "cyan", "blue", "magenta"
@@ -943,7 +944,7 @@ void PlatformSurfaces::init()
         sm_instance->m_right[c][1] = SDL_CALLS::LoadBMP(file);
     }
 
-    for (int c = ET_RED; c < ET_TOTAL_NUMBER; c++)
+    for (int c = ET_RED; c <= ET_MAGENTA; c++)
     {
         for (int i=0; i<=1; i++)
         {
@@ -957,6 +958,14 @@ void PlatformSurfaces::init()
         }
     }
 
+    snprintf(file, 1024, "%s/leftfuel.bmp", dir.c_str());
+    sm_instance->m_left[ET_FUEL][0] = SDL_CALLS::LoadBMP(file);
+    sm_instance->m_left[ET_FUEL][1] = SDL_CALLS::LoadBMP(file);
+
+    snprintf(file, 1024, "%s/rightfuel.bmp", dir.c_str());
+    sm_instance->m_right[ET_FUEL][0] = SDL_CALLS::LoadBMP(file);
+    sm_instance->m_right[ET_FUEL][1] = SDL_CALLS::LoadBMP(file);
+
     snprintf(file, 1024, "%s/center.bmp", dir.c_str());
     sm_instance->m_center = SDL_CALLS::LoadBMP(file);
 }
@@ -1017,6 +1026,20 @@ SDL_Surface *PlatformSurfaces::createSurface(
     return s;
 }
 
+//----------------------------------------------------------------------------
+Uint16 PlatformSurfaces::getPlatformHeight() const
+{
+    for (Uint16 y = 0; y < m_center->h; y++)
+    {
+        if (SDL_TOOLS::getPixel(m_center, 8, y) != 0)
+        {
+            return 16 - y;
+        }
+    }
+
+    return 0;
+}
+
 
 
 //============================================================================
@@ -1167,6 +1190,258 @@ void SwitchSurfaces::destroy()
 
 
 
+//============================================================================
+// Implementation of ThornSurfaces.h
+//============================================================================
+
+//----------------------------------------------------------------------------
+ThornSurfaces *ThornSurfaces::sm_instance = NULL;
+
+//----------------------------------------------------------------------------
+ThornSurfaces::ThornSurfaces()
+{
+    memset(m_base, 0, sizeof(m_base));
+    memset(m_shaft, 0, sizeof(m_shaft));
+    memset(m_tip, 0, sizeof(m_tip));
+}
+
+//----------------------------------------------------------------------------
+ThornSurfaces::~ThornSurfaces()
+{
+    // Zap all dynamically created thorn surfaces.
+    for (SurfaceIter iter = m_surfaceMap.begin();
+         iter != m_surfaceMap.end(); ++iter)
+    {
+        ZAP_SURFACE(iter->second);
+    }
+    m_surfaceMap.clear();
+
+    // Zap the thorn surface tiles.
+    for (int i=0; i<4; i++)
+    {
+        ZAP_SURFACE(m_base[i]);
+        ZAP_SURFACE(m_shaft[i]);
+        ZAP_SURFACE(m_tip[i]);
+    }
+}
+
+//----------------------------------------------------------------------------
+void ThornSurfaces::init()
+{
+    std::string dir;
+    dir.append(Configuration::getInstance()->getDataDir())
+        .append("/gfx/decoration/thorn/");
+
+    sm_instance = new ThornSurfaces();
+    SDL_Surface *s = NULL;
+    char file[1024];
+
+    snprintf(file, 1024, "%s/base.bmp", dir.c_str());
+    s = SDL_CALLS::LoadBMP(file);
+
+    for (unsigned i=0; i<4; i++)
+    {
+        sm_instance->m_base[i] = SDL_TOOLS::rotate(s, i*90);
+    }
+
+    SDL_CALLS::FreeSurface(s);
+
+    snprintf(file, 1024, "%s/shaft.bmp", dir.c_str());
+    s = SDL_CALLS::LoadBMP(file);
+
+    for (unsigned i=0; i<4; i++)
+    {
+        sm_instance->m_shaft[i] = SDL_TOOLS::rotate(s, i*90);
+    }
+
+    SDL_CALLS::FreeSurface(s);
+
+    snprintf(file, 1024, "%s/tip.bmp", dir.c_str());
+    s = SDL_CALLS::LoadBMP(file);
+
+    for (unsigned i=0; i<4; i++)
+    {
+        sm_instance->m_tip[i] = SDL_TOOLS::rotate(s, i*90);
+    }
+
+    SDL_CALLS::FreeSurface(s);
+}
+
+//----------------------------------------------------------------------------
+void ThornSurfaces::destroy()
+{
+    ZAP_POINTER(sm_instance);
+}
+
+//----------------------------------------------------------------------------
+const SDL_Surface *ThornSurfaces::getSurface(OrientatingDecorationBase::Orientation o,
+                                             unsigned tileSize, unsigned size)
+{
+    assert(o >= 0 && o < 4);
+
+    SDL_Surface *s = NULL;
+
+    SurfaceKey key(o, tileSize, size);
+    SurfaceCIter iter = m_surfaceMap.find(key);
+    if (iter != m_surfaceMap.end())
+    {
+        s = iter->second;
+    }
+    else
+    {
+        s = createSurface(o, tileSize, size);
+        m_surfaceMap[key] = s;
+    }
+
+    return s;
+}
+
+//----------------------------------------------------------------------------
+SDL_Surface *ThornSurfaces::createSurface(OrientatingDecorationBase::Orientation o,
+                                          unsigned tileSize,
+                                          unsigned size) const
+{
+    unsigned w = 0;
+    unsigned h = 0;
+
+    unsigned bh = getBaseHeight();
+
+    switch (o)
+    {
+    case OrientatingDecorationBase::O_TOP:
+    case OrientatingDecorationBase::O_BOTTOM:
+        w = 16;
+        h = tileSize*16;
+        break;
+
+    case OrientatingDecorationBase::O_LEFT:
+    case OrientatingDecorationBase::O_RIGHT:
+        w = tileSize*16;
+        h = 16;
+    }
+
+    SDL_Surface *s = SDL_CALLS::CreateRGBSurface(SDL_SWSURFACE, w, h, 32);
+    SDL_Rect r = { 0, 0, 16, 16 };
+    Uint16 hr = size % 16;
+
+    switch (o)
+    {
+    case OrientatingDecorationBase::O_TOP:
+    {
+        r.x = 0;
+        r.y = 0;
+        SDL_CALLS::BlitSurface(m_base[o], NULL, s, &r);
+
+        r.y += bh + size;
+        SDL_CALLS::BlitSurface(m_tip[o], NULL, s, &r);
+
+        r.y -= 16;
+        for (; r.y >= (Sint16)bh; r.y -= 16)
+        {
+            SDL_CALLS::BlitSurface(m_shaft[o], NULL, s, &r);
+        }
+
+        if (hr > 0)
+        {
+            SDL_Rect r2 = { 0, 16-hr, 16, hr };
+            r.y = bh;
+            SDL_CALLS::BlitSurface(m_shaft[o], &r2, s, &r);
+        }
+    }   break;
+
+    case OrientatingDecorationBase::O_RIGHT:
+    {
+        r.x = w - 16;
+        r.y = 0;
+        SDL_CALLS::BlitSurface(m_base[o], NULL, s, &r);
+
+        r.x -= bh + size;
+        SDL_CALLS::BlitSurface(m_tip[o], NULL, s, &r);
+
+        r.x += 16;
+        for (; r.x <= (Sint16)(w-bh-16); r.x += 16)
+        {
+            SDL_CALLS::BlitSurface(m_shaft[o], NULL, s, &r);
+        }
+
+        if (hr > 0)
+        {
+            SDL_Rect r2 = { 0, 0, hr, 16 };
+            SDL_CALLS::BlitSurface(m_shaft[o], &r2, s, &r);
+        }
+    }   break;
+
+    case OrientatingDecorationBase::O_BOTTOM:
+    {
+        r.x = 0;
+        r.y = h - 16;
+        SDL_CALLS::BlitSurface(m_base[o], NULL, s, &r);
+
+        r.y -= bh + size;
+        SDL_CALLS::BlitSurface(m_tip[o], NULL, s, &r);
+
+        r.y += 16;
+        for (; r.y <= (Sint16)(h-bh-16); r.y += 16)
+        {
+            SDL_CALLS::BlitSurface(m_shaft[o], NULL, s, &r);
+        }
+
+        if (hr > 0)
+        {
+            SDL_Rect r2 = { 0, 0, 16, hr };
+            SDL_CALLS::BlitSurface(m_shaft[o], &r2, s, &r);
+        }
+    }   break;
+
+    case OrientatingDecorationBase::O_LEFT:
+    {
+        r.x = 0;
+        r.y = 0;
+        SDL_CALLS::BlitSurface(m_base[o], NULL, s, &r);
+
+        r.x += bh + size;
+        SDL_CALLS::BlitSurface(m_tip[o], NULL, s, &r);
+
+        r.x -= 16;
+        for (; r.x >= (Sint16)bh; r.x -= 16)
+        {
+            SDL_CALLS::BlitSurface(m_shaft[o], NULL, s, &r);
+        }
+
+        if (hr > 0)
+        {
+            SDL_Rect r2 = { 16-hr, 0, hr, 16 };
+            r.x = bh;
+            SDL_CALLS::BlitSurface(m_shaft[o], &r2, s, &r);
+        }
+    }   break;
+    }
+
+
+    SDL_CALLS::SetColorKey(
+        s, SDL_SRCCOLORKEY, SDL_MapRGB(s->format, 0, 0, 0));
+
+    return s;
+}
+
+//----------------------------------------------------------------------------
+Uint16 ThornSurfaces::getBaseHeight() const
+{
+    const SDL_Surface *s = m_base[OrientatingDecorationBase::O_BOTTOM];
+
+    Uint16 y = 0;
+    for (y = 0; y<s->h; y++)
+    {
+        if (SDL_TOOLS::getPixel(s, s->w/2, y))
+        {
+            break;
+        }
+    }
+
+    return 16 - y;
+}
+
+
 
 //============================================================================
 // Implementation of TurretSurfaces.h
