@@ -3,7 +3,6 @@
 
 #include <cassert>
 
-#include "Exception.h"
 #include "SDLMixerCalls.h"
 
 //----------------------------------------------------------------------------
@@ -39,7 +38,7 @@ class SoundFactory
     }
 
     //------------------------------------------------------------------------
-    static void init() throw (Exception);
+    static void init();
     static void destroy();
 
     static inline SoundFactory *getInstance() { return sm_instance; }
