@@ -10,6 +10,7 @@
 #include "PlayerStatus.h"
 
 #include "AllObjects.h"
+#include "ObjectVisitors.h"
 #include "ObjectRepository.h"
 #include "GameBridge.h"
 #include "GameControlBase.h"
@@ -33,6 +34,43 @@ class GameControlTest : public CppUnit::TestFixture
 
     CPPUNIT_TEST_SUITE_END();
 
+
+    //------------------------------------------------------------------------
+    class UpdateSurfaceObjectVisitor : public ObjectVisitor
+    {
+    public:
+        //--------------------------------------------------------------------
+        UpdateSurfaceObjectVisitor() {}
+        ~UpdateSurfaceObjectVisitor() {}
+
+    private:
+        //--------------------------------------------------------------------
+        void do_visit(Barrier *b) { do_do_visit(b); }
+        void do_visit(BlackHole *b) { do_do_visit(b); }
+        void do_visit(Crate *c) { do_do_visit(c); }
+        void do_visit(Grenade *g) { do_do_visit(g); }
+        void do_visit(Grinder *g) { do_do_visit(g); }
+        void do_visit(MagnetBase *m) { do_do_visit(m); }
+        void do_visit(Missile *m) { do_do_visit(m); }
+        void do_visit(MortarBase *m) { do_do_visit(m); }
+        void do_visit(ParticleBase *p) { do_do_visit(p); }
+        void do_visit(ParticleFountainBase *f) { do_do_visit(f); }
+        void do_visit(Platform *p) { do_do_visit(p); }
+        void do_visit(ProjectileBase *p) { do_do_visit(p); }
+        void do_visit(SAMBatteryBase *s) { do_do_visit(s); }
+        void do_visit(Ship *s) { do_do_visit(s); }
+        void do_visit(SwitchBase *s) { do_do_visit(s); }
+        void do_visit(Tank *t) { do_do_visit(t); }
+        void do_visit(Thorn *t) { do_do_visit(t); }
+        void do_visit(TurretBase *t) { do_do_visit(t); }
+
+        //--------------------------------------------------------------------
+        void do_do_visit(ObjectBase *o)
+        {
+            o->updateSurface();
+        }
+    };
+
 public:
 
     //------------------------------------------------------------------------
@@ -67,7 +105,8 @@ protected:
     //------------------------------------------------------------------------
     void testLandObjectives()
     {
-        GameControlBase::init("test", "land.xml");
+        initLevel("land.xml");
+
         GameControlBase *gc = GameControlBase::getInstance();
         Ship *ship = gc->getPlayerShip();
 
@@ -100,7 +139,8 @@ protected:
     //------------------------------------------------------------------------
     void testDestroyObjectives()
     {
-        GameControlBase::init("test", "destroy.xml");
+        initLevel("destroy.xml");
+
         GameControlBase *gc = GameControlBase::getInstance();
         Ship *ship = gc->getPlayerShip();
 
@@ -146,7 +186,8 @@ protected:
     //------------------------------------------------------------------------
     void testRescueObjectives()
     {
-        GameControlBase::init("test", "rescue.xml");
+        initLevel("rescue.xml");
+
         GameControlBase *gc = GameControlBase::getInstance();
         Ship *ship = gc->getPlayerShip();
 
@@ -205,7 +246,8 @@ protected:
     //------------------------------------------------------------------------
     void testRescueCrashAfterPickup()
     {
-        GameControlBase::init("test", "rescue.xml");
+        initLevel("rescue.xml");
+
         GameControlBase *gc = GameControlBase::getInstance();
         Ship *ship = gc->getPlayerShip();
 
@@ -225,7 +267,8 @@ protected:
     //------------------------------------------------------------------------
     void testRescueCrashAfterPickupLastCrate()
     {
-        GameControlBase::init("test", "rescue.xml");
+        initLevel("rescue.xml");
+
         GameControlBase *gc = GameControlBase::getInstance();
         Ship *ship = gc->getPlayerShip();
 
@@ -258,7 +301,8 @@ protected:
     //------------------------------------------------------------------------
     void testRescueCrashAfterCrateUnloading()
     {
-        GameControlBase::init("test", "rescue.xml");
+        initLevel("rescue.xml");
+
         GameControlBase *gc = GameControlBase::getInstance();
         Ship *ship = gc->getPlayerShip();
 
@@ -283,7 +327,8 @@ protected:
     //------------------------------------------------------------------------
     void testRescueCrashAfterCrateUnloadingDelay()
     {
-        GameControlBase::init("test", "rescue.xml");
+        initLevel("rescue.xml");
+
         GameControlBase *gc = GameControlBase::getInstance();
         Ship *ship = gc->getPlayerShip();
 
@@ -324,7 +369,8 @@ protected:
     //------------------------------------------------------------------------
     void testLandCrashBeforeLandOnHomePlatform()
     {
-        GameControlBase::init("test", "landhome.xml");
+        initLevel("landhome.xml");
+
         GameControlBase *gc = GameControlBase::getInstance();
         Ship *ship = gc->getPlayerShip();
         
@@ -348,7 +394,8 @@ protected:
     //------------------------------------------------------------------------
     void testEventHandlerOnPickup()
     {
-        GameControlBase::init("test", "onpickup.xml");
+        initLevel("onpickup.xml");
+
         GameControlBase *gc = GameControlBase::getInstance();
         Ship *ship = gc->getPlayerShip();
 
@@ -391,7 +438,8 @@ protected:
     //------------------------------------------------------------------------
     void testOutOfFuel()
     {
-        GameControlBase::init("test", "land.xml");
+        initLevel("land.xml");
+
         GameControlBase *gc = GameControlBase::getInstance();
         Ship *ship = gc->getPlayerShip();
 
@@ -409,6 +457,17 @@ protected:
 
 private:
 
+    //------------------------------------------------------------------------
+    void initLevel(const char *name)
+    {
+        GameControlBase::init("test", name);
+
+        // The surfaces of all objects must be initialized,
+        // since we won't execute the whole update loop of the PlayGround.
+        UpdateSurfaceObjectVisitor v;
+        ObjectRepository::getInstance()->acceptAll(v);
+    }
+
     //------------------------------------------------------------------------
     ObjectBase *getObject(unsigned id)
     {
@@ -502,6 +561,11 @@ private:
         // The only relevant action of PlayGround::update() needed here.
         ObjectRepository::getInstance()->removeObjectsToRemove();
 
+        // This is a part of the blitting step,
+        // that's necessary for test cases with initial hidden objects.
+        UpdateSurfaceObjectVisitor v;
+        ObjectRepository::getInstance()->acceptAll(v);
+
         gc->onPostUpdate();
     }
     
