@@ -1,3 +1,5 @@
+#include <memory>
+
 #include <cppunit/TestFixture.h>
 #include <cppunit/extensions/HelperMacros.h>
 
@@ -354,9 +356,9 @@ protected:
             TopMortar mortar(mortarInit);
             MortarBarrel barrel(barrelInit);
 
-            MortarGrenade grenade(&mortar, &barrel);
+            std::auto_ptr<Grenade> grenade(barrel.createGrenade(&mortar));
 
-            CPPUNIT_ASSERT(!ObjectBase::isCollision(&mortar, &grenade));
+            CPPUNIT_ASSERT(!ObjectBase::isCollision(&mortar, grenade.get()));
         }
         while (0);
 
@@ -369,9 +371,9 @@ protected:
             BottomMortar mortar(mortarInit);
             MortarBarrel barrel(barrelInit);
 
-            MortarGrenade grenade(&mortar, &barrel);
+            std::auto_ptr<Grenade> grenade(barrel.createGrenade(&mortar));
 
-            CPPUNIT_ASSERT(!ObjectBase::isCollision(&mortar, &grenade));
+            CPPUNIT_ASSERT(!ObjectBase::isCollision(&mortar, grenade.get()));
         }
         while (0);
 
@@ -384,9 +386,9 @@ protected:
             LeftMortar mortar(mortarInit);
             MortarBarrel barrel(barrelInit);
 
-            MortarGrenade grenade(&mortar, &barrel);
+            std::auto_ptr<Grenade> grenade(barrel.createGrenade(&mortar));
 
-            CPPUNIT_ASSERT(!ObjectBase::isCollision(&mortar, &grenade));
+            CPPUNIT_ASSERT(!ObjectBase::isCollision(&mortar, grenade.get()));
         }
         while (0);
 
@@ -399,9 +401,9 @@ protected:
             RightMortar mortar(mortarInit);
             MortarBarrel barrel(barrelInit);
 
-            MortarGrenade grenade(&mortar, &barrel);
+            std::auto_ptr<Grenade> grenade(barrel.createGrenade(&mortar));
 
-            CPPUNIT_ASSERT(!ObjectBase::isCollision(&mortar, &grenade));
+            CPPUNIT_ASSERT(!ObjectBase::isCollision(&mortar, grenade.get()));
         }
         while (0);
     }
