@@ -672,6 +672,7 @@ class SDLToolsTest : public CppUnit::TestFixture
     CPPUNIT_TEST(testUnionReuseParameter);
 
     CPPUNIT_TEST(testRotate);
+    CPPUNIT_TEST(testFlip);
 
     CPPUNIT_TEST(testIsCollision);
     CPPUNIT_TEST(testGetAngle);
@@ -1033,6 +1034,27 @@ protected:
         SDL_CALLS::FreeSurface(i4);
     }
 
+    //------------------------------------------------------------------------
+    void testFlip()
+    {
+        SDL_Surface *flip = SDL_CALLS::LoadBMP("gfx/flip.bmp");
+        SDL_Surface *flipX = SDL_CALLS::LoadBMP("gfx/flipx.bmp");
+        SDL_Surface *flipY = SDL_CALLS::LoadBMP("gfx/flipy.bmp");
+        SDL_Surface *f;
+
+        f = SDL_TOOLS::flipX(flip);
+        helperCheckEqual(f, flipX);
+        SDL_CALLS::FreeSurface(f);
+
+        f = SDL_TOOLS::flipY(flip);
+        helperCheckEqual(f, flipY);
+        SDL_CALLS::FreeSurface(f);
+
+        SDL_CALLS::FreeSurface(flip);
+        SDL_CALLS::FreeSurface(flipX);
+        SDL_CALLS::FreeSurface(flipY);
+    }
+
 
     //------------------------------------------------------------------------
     void testIsCollision()
